-- Alter ntext to nvarchar(max) 
-- tbl_Billing
-- tbl_BillingAudit
-- tbl_CallAudit
-- tbl_CallAuditAttach
-- tbl_CallAuditAttachTemp
-- tbl_Calls

/*
So if we need use T-SQL to move data from one place to another one. It is recommended to use TABLOCK option on the destination table. With a few other constraints, the query can be executed with minimal logging.

The few constraints are:

The database must be in bulk logged recovery model.
The destination table must be empty or without clustered index.
There is no non-clustered index on the destination table.
*/

-- WITH (TABLOCK)
-- The above statement used in INSERT INTO statement will execute with minimal logging, hence improve execution time.
-- To enable "TABLOCK", the database must be in BULK_LOGGED or SIMPLE Recovery mode.

-- Set Recovery Mode to "SIMPLE"
PRINT 'Set Recovery Mode to "SIMPLE"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY SIMPLE
GO

Use [versaSRS]
GO

PRINT 'Start Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

-- Drop FullText index on [dbo].[tbl_CallAudit]
Print 'Drop FullText index on [dbo].[tbl_CallAudit]'
GO
IF (EXISTS(SELECT * FROM sys.objects o inner join sys.fulltext_indexes fi on fi.object_id = o.object_id WHERE o.[object_id] = OBJECT_ID(N'[dbo].[tbl_CallAudit]') AND [type]='U'))
	DROP FULLTEXT INDEX ON [dbo].[tbl_CallAudit]
GO

-- Drop fulltext catalog [Call Search]
Print 'Drop fulltext catalog [Call Search]'
GO
IF (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Call Search'))
	DROP FULLTEXT CATALOG [Call Search]
GO

-- Create new table tbl_Billing_New with correct structure
PRINT 'Create new table tbl_Billing_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_Billing]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_Billing' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_Billing_New] (
			[CallID]              [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_Billing_New] PRIMARY KEY CLUSTERED 
	(
		[CallID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_Billing to tbl_Billing_New
PRINT 'Copy rows from tbl_Billing to tbl_Billing_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_Billing_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_Billing_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_Billing_New] WITH (TABLOCK) 
			   ([CallID]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_Billing].[CallID]
			   ,[dbo].[tbl_Billing].[SiteID]
			   ,[dbo].[tbl_Billing].[NumTransactions]
			   ,[dbo].[tbl_Billing].[CumulativeTime]
			   ,[dbo].[tbl_Billing].[EstimatedTime]
			   ,[dbo].[tbl_Billing].[Charge]
			   ,[dbo].[tbl_Billing].[ChargeType]
			   ,[dbo].[tbl_Billing].[ChargeCompany]
			   ,[dbo].[tbl_Billing].[BilledTo]
			   ,[dbo].[tbl_Billing].[SLA]
			   ,[dbo].[tbl_Billing].[Quote]
			   ,[dbo].[tbl_Billing].[RefNum]
			   ,[dbo].[tbl_Billing].[Notes]
			   ,[dbo].[tbl_Billing].[SysReplication] FROM [dbo].[tbl_Billing]
		LEFT OUTER JOIN [dbo].[tbl_Billing_New] ON [dbo].[tbl_Billing_New].[CallID] = [dbo].[tbl_Billing].[CallID] 
		WHERE [dbo].[tbl_Billing_New].[CallID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_Billing_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1;

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_Billing_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(CallID) FROM [dbo].[tbl_Billing]
	SELECT @NewCount = COUNT(CallID) FROM [dbo].[tbl_Billing_New]

	SET @PrintMsg = 'Count [dbo].[tbl_Billing]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_Billing_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_Billing]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_Billing]

		SET @PrintMsg = 'Rename name new table tbl_Billing_New to tbl_Billing'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Billing_New', 'tbl_Billing'

		SET @PrintMsg = 'Rename PK_tbl_Billing_New Constraints to PK_tbl_Billing'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Billing.PK_tbl_Billing_New', 'PK_tbl_Billing', 'INDEX'

	END
END

-- Create new table tbl_BillingAudit_New with correct structure
PRINT 'Create new table tbl_BillingAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_BillingAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_BillingAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_BillingAudit_New] (
			[ActionCount]         [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[BilledTime]          [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_BillingAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO


-- Copy rows from tbl_BillingAudit to tbl_BillingAudit_New
PRINT 'Copy rows from tbl_BillingAudit to tbl_BillingAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_BillingAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_BillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_BillingAudit_New]  WITH (TABLOCK) 
			   ([ActionCount]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[BilledTime]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_BillingAudit].[ActionCount]
			   ,[dbo].[tbl_BillingAudit].[SiteID]
			   ,[dbo].[tbl_BillingAudit].[NumTransactions]
			   ,[dbo].[tbl_BillingAudit].[BilledTime]
			   ,[dbo].[tbl_BillingAudit].[CumulativeTime]
			   ,[dbo].[tbl_BillingAudit].[EstimatedTime]
			   ,[dbo].[tbl_BillingAudit].[Charge]
			   ,[dbo].[tbl_BillingAudit].[ChargeType]
			   ,[dbo].[tbl_BillingAudit].[ChargeCompany]
			   ,[dbo].[tbl_BillingAudit].[BilledTo]
			   ,[dbo].[tbl_BillingAudit].[SLA]
			   ,[dbo].[tbl_BillingAudit].[Quote]
			   ,[dbo].[tbl_BillingAudit].[RefNum]
			   ,[dbo].[tbl_BillingAudit].[Notes]
			   ,[dbo].[tbl_BillingAudit].[SysReplication] FROM [dbo].[tbl_BillingAudit]
		LEFT OUTER JOIN [dbo].[tbl_BillingAudit_New] ON [dbo].[tbl_BillingAudit_New].[ActionCount] = [dbo].[tbl_BillingAudit].[ActionCount] 
		WHERE [dbo].[tbl_BillingAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_BillingAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_BillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_BillingAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_BillingAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_BillingAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_BillingAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_BillingAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_BillingAudit]

		SET @PrintMsg = 'Rename name new table tbl_BillingAudit_New to tbl_BillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_BillingAudit_New', 'tbl_BillingAudit'

		SET @PrintMsg = 'Rename PK_tbl_BillingAudit_New Constraints to PK_tbl_BillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_BillingAudit.PK_tbl_BillingAudit_New', 'PK_tbl_BillingAudit', 'INDEX'

	END
END

-- Create new table tbl_Calls_New with correct structure
PRINT 'Create new table tbl_Calls_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_Calls]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Description' AND TABLE_NAME= 'tbl_Calls' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_Calls_New] (
			[CallID]                     [int] NOT NULL,
			[CallPID]                    [int] NULL,
			[SiteID]                     [int] NULL,
			[HDUserID]                   [int] NULL,
			[DateEntered]                [datetime] NULL,
			[LastUpdated]                [datetime] NULL,
			[Closed]                     [datetime] NULL,
			[PerformedOn]                [datetime] NULL,
			[ResUserID]                  [int] NULL,
			[DateStarted]                [datetime] NULL,
			[ElapsedTime]                [int] NULL,
			[CallType]                   [int] NULL,
			[ReceivedBy]                 [int] NULL,
			[CallStatusID]               [int] NULL,
			[Subject]                    [nvarchar](500) NULL,
			[Description]                [nvarchar](max) NULL,
			[SolutionTypeID]             [int] NULL,
			[Solution]                   [nvarchar](max) NULL,
			[HotNewsID]                  [int] NULL,
			[PriorityID]                 [int] NULL,
			[Key1]                       [int] NULL,
			[Key2]                       [int] NULL,
			[Key3]                       [int] NULL,
			[DueDate]                    [datetime] NULL,
			[QueueID]                    [int] NULL,
			[GroupID]                    [int] NULL,
			[UserID]                     [int] NULL,
			[EstSolDate]                 [datetime] NULL,
			[Notification]               [int] NULL,
			[EmailNotification]          [bit] NULL,
			[ClosedOnCall]               [bit] NULL,
			[CompanyName]                [nvarchar](250) NULL,
			[CompanyID]                  [int] NULL,
			[ContactID]                  [int] NULL,
			[CompanyIDGUID]              [varchar](100) NULL,
			[ContactIDGUID]              [varchar](100) NULL,
			[FirstName]                  [nvarchar](100) NULL,
			[LastName]                   [nvarchar](100) NULL,
			[Email]                      [nvarchar](100) NULL,
			[Username]                   [nvarchar](200) NULL,
			[Phone]                      [nvarchar](100) NULL,
			[Division]                   [nvarchar](200) NULL,
			[Department]                 [nvarchar](200) NULL,
			[Location]                   [nvarchar](200) NULL,
			[Computer]                   [nvarchar](200) NULL,
			[ReqCompanyName]             [nvarchar](250) NULL,
			[ReqCompanyID]               [int] NULL,
			[ReqContactID]               [int] NULL,
			[ReqCompanyIDGUID]           [varchar](100) NULL,
			[ReqContactIDGUID]           [varchar](100) NULL,
			[ReqFirstName]               [nvarchar](100) NULL,
			[ReqLastName]                [nvarchar](100) NULL,
			[ReqEmail]                   [nvarchar](100) NULL,
			[ReqUsername]                [nvarchar](200) NULL,
			[ReqPhone]                   [nvarchar](100) NULL,
			[ReqDivision]                [nvarchar](200) NULL,
			[ReqDepartment]              [nvarchar](200) NULL,
			[ReqLocation]                [nvarchar](200) NULL,
			[ReqComputer]                [nvarchar](200) NULL,
			[DueDateNotification]        [bit] NULL,
			[EstSolDateNotification]     [bit] NULL,
			[OpenNotificationOnLog]      [bit] NULL,
			[CloseNotificationOnLog]     [bit] NULL,
			[SysReplication]             [int] NULL,
			[CallLocked]                 [int] NULL,
			[ClosureTypeID]              [int] NULL,
			[ArchiveID]                  [int] NULL,
			[ArchiveDate]                [datetime] NULL,
			[UrgencyID]                  [int] NULL,
			[RiskID]                     [int] NULL,
			[ServiceAreaID]              [int] NULL,
			[ProductTypeID]              [int] NULL,
			[ProductID]                  [int] NULL,
			[ImpactID]                   [int] NULL,
			[SymptomCodeID]              [int] NULL,
			[CauseCodeID]                [int] NULL,
			[JobTitle]                   [nvarchar](200) NULL,
			[ReqJobTitle]                [nvarchar](200) NULL,
	 CONSTRAINT [PK_tbl_Calls_New] PRIMARY KEY CLUSTERED 
	(
		[CallID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_Calls to tbl_Calls_New
PRINT 'Copy rows from tbl_Calls to tbl_Calls_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_Calls_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_Calls_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_Calls_New]  WITH (TABLOCK) 
			   ([CallID]
			   ,[CallPID]
			   ,[SiteID]
			   ,[HDUserID]
			   ,[DateEntered]
			   ,[LastUpdated]
			   ,[Closed]
			   ,[PerformedOn]
			   ,[ResUserID]
			   ,[DateStarted]
			   ,[ElapsedTime]
			   ,[CallType]
			   ,[ReceivedBy]
			   ,[CallStatusID]
			   ,[Subject]
			   ,[Description]
			   ,[SolutionTypeID]
			   ,[Solution]
			   ,[HotNewsID]
			   ,[PriorityID]
			   ,[Key1]
			   ,[Key2]
			   ,[Key3]
			   ,[DueDate]
			   ,[QueueID]
			   ,[GroupID]
			   ,[UserID]
			   ,[EstSolDate]
			   ,[Notification]
			   ,[EmailNotification]
			   ,[ClosedOnCall]
			   ,[CompanyName]
			   ,[CompanyID]
			   ,[ContactID]
			   ,[CompanyIDGUID]
			   ,[ContactIDGUID]
			   ,[FirstName]
			   ,[LastName]
			   ,[Email]
			   ,[Username]
			   ,[Phone]
			   ,[Division]
			   ,[Department]
			   ,[Location]
			   ,[Computer]
			   ,[ReqCompanyName]
			   ,[ReqCompanyID]
			   ,[ReqContactID]
			   ,[ReqCompanyIDGUID]
			   ,[ReqContactIDGUID]
			   ,[ReqFirstName]
			   ,[ReqLastName]
			   ,[ReqEmail]
			   ,[ReqUsername]
			   ,[ReqPhone]
			   ,[ReqDivision]
			   ,[ReqDepartment]
			   ,[ReqLocation]
			   ,[ReqComputer]
			   ,[DueDateNotification]
			   ,[EstSolDateNotification]
			   ,[OpenNotificationOnLog]
			   ,[CloseNotificationOnLog]
			   ,[SysReplication]
			   ,[CallLocked]
			   ,[ClosureTypeID]
			   ,[ArchiveID]
			   ,[ArchiveDate]
			   ,[UrgencyID]
			   ,[RiskID]
			   ,[ServiceAreaID]
			   ,[ProductTypeID]
			   ,[ProductID]
			   ,[ImpactID]
			   ,[SymptomCodeID]
			   ,[CauseCodeID]
			   ,[JobTitle]
			   ,[ReqJobTitle])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_Calls].[CallID]
			   ,[dbo].[tbl_Calls].[CallPID]
			   ,[dbo].[tbl_Calls].[SiteID]
			   ,[dbo].[tbl_Calls].[HDUserID]
			   ,[dbo].[tbl_Calls].[DateEntered]
			   ,[dbo].[tbl_Calls].[LastUpdated]
			   ,[dbo].[tbl_Calls].[Closed]
			   ,[dbo].[tbl_Calls].[PerformedOn]
			   ,[dbo].[tbl_Calls].[ResUserID]
			   ,[dbo].[tbl_Calls].[DateStarted]
			   ,[dbo].[tbl_Calls].[ElapsedTime]
			   ,[dbo].[tbl_Calls].[CallType]
			   ,[dbo].[tbl_Calls].[ReceivedBy]
			   ,[dbo].[tbl_Calls].[CallStatusID]
			   ,[dbo].[tbl_Calls].[Subject]
			   ,[dbo].[tbl_Calls].[Description]
			   ,[dbo].[tbl_Calls].[SolutionTypeID]
			   ,[dbo].[tbl_Calls].[Solution]
			   ,[dbo].[tbl_Calls].[HotNewsID]
			   ,[dbo].[tbl_Calls].[PriorityID]
			   ,[dbo].[tbl_Calls].[Key1]
			   ,[dbo].[tbl_Calls].[Key2]
			   ,[dbo].[tbl_Calls].[Key3]
			   ,[dbo].[tbl_Calls].[DueDate]
			   ,[dbo].[tbl_Calls].[QueueID]
			   ,[dbo].[tbl_Calls].[GroupID]
			   ,[dbo].[tbl_Calls].[UserID]
			   ,[dbo].[tbl_Calls].[EstSolDate]
			   ,[dbo].[tbl_Calls].[Notification]
			   ,[dbo].[tbl_Calls].[EmailNotification]
			   ,[dbo].[tbl_Calls].[ClosedOnCall]
			   ,[dbo].[tbl_Calls].[CompanyName]
			   ,[dbo].[tbl_Calls].[CompanyID]
			   ,[dbo].[tbl_Calls].[ContactID]
			   ,[dbo].[tbl_Calls].[CompanyIDGUID]
			   ,[dbo].[tbl_Calls].[ContactIDGUID]
			   ,[dbo].[tbl_Calls].[FirstName]
			   ,[dbo].[tbl_Calls].[LastName]
			   ,[dbo].[tbl_Calls].[Email]
			   ,[dbo].[tbl_Calls].[Username]
			   ,[dbo].[tbl_Calls].[Phone]
			   ,[dbo].[tbl_Calls].[Division]
			   ,[dbo].[tbl_Calls].[Department]
			   ,[dbo].[tbl_Calls].[Location]
			   ,[dbo].[tbl_Calls].[Computer]
			   ,[dbo].[tbl_Calls].[ReqCompanyName]
			   ,[dbo].[tbl_Calls].[ReqCompanyID]
			   ,[dbo].[tbl_Calls].[ReqContactID]
			   ,[dbo].[tbl_Calls].[ReqCompanyIDGUID]
			   ,[dbo].[tbl_Calls].[ReqContactIDGUID]
			   ,[dbo].[tbl_Calls].[ReqFirstName]
			   ,[dbo].[tbl_Calls].[ReqLastName]
			   ,[dbo].[tbl_Calls].[ReqEmail]
			   ,[dbo].[tbl_Calls].[ReqUsername]
			   ,[dbo].[tbl_Calls].[ReqPhone]
			   ,[dbo].[tbl_Calls].[ReqDivision]
			   ,[dbo].[tbl_Calls].[ReqDepartment]
			   ,[dbo].[tbl_Calls].[ReqLocation]
			   ,[dbo].[tbl_Calls].[ReqComputer]
			   ,[dbo].[tbl_Calls].[DueDateNotification]
			   ,[dbo].[tbl_Calls].[EstSolDateNotification]
			   ,[dbo].[tbl_Calls].[OpenNotificationOnLog]
			   ,[dbo].[tbl_Calls].[CloseNotificationOnLog]
			   ,[dbo].[tbl_Calls].[SysReplication]
			   ,[dbo].[tbl_Calls].[CallLocked]
			   ,[dbo].[tbl_Calls].[ClosureTypeID]
			   ,[dbo].[tbl_Calls].[ArchiveID]
			   ,[dbo].[tbl_Calls].[ArchiveDate]
			   ,[dbo].[tbl_Calls].[UrgencyID]
			   ,[dbo].[tbl_Calls].[RiskID]
			   ,[dbo].[tbl_Calls].[ServiceAreaID]
			   ,[dbo].[tbl_Calls].[ProductTypeID]
			   ,[dbo].[tbl_Calls].[ProductID]
			   ,[dbo].[tbl_Calls].[ImpactID]
			   ,[dbo].[tbl_Calls].[SymptomCodeID]
			   ,[dbo].[tbl_Calls].[CauseCodeID]
			   ,[dbo].[tbl_Calls].[JobTitle]
			   ,[dbo].[tbl_Calls].[ReqJobTitle] FROM [dbo].[tbl_Calls]
		LEFT OUTER JOIN [dbo].[tbl_Calls_New] ON [dbo].[tbl_Calls_New].[CallID] = [dbo].[tbl_Calls].[CallID] 
		WHERE [dbo].[tbl_Calls_New].[CallID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_Calls_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_Calls_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(CallID) FROM [dbo].[tbl_Calls]
	SELECT @NewCount = COUNT(CallID) FROM [dbo].[tbl_Calls_New]

	SET @PrintMsg = 'Count [dbo].[tbl_Calls]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_Calls_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_Calls]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_Calls]

		SET @PrintMsg = 'Rename name new table tbl_Calls_New to tbl_Calls'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Calls_New', 'tbl_Calls'

		SET @PrintMsg = 'Rename PK_tbl_Calls_New Constraints to PK_tbl_Calls'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Calls.PK_tbl_Calls_New', 'PK_tbl_Calls', 'INDEX'

	END
END

-- Create new table tbl_CallAudit_New with correct structure
PRINT 'Create new table tbl_CallAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_CallAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_CallAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_CallAudit_New] (
		[ActionCount] [int] NOT NULL,
		[CallID] [int] NULL,
		[LinkID] [int] NULL,
		[SiteID] [int] NULL,
		[ActionID] [int] NULL,
		[ActionDate] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[TimeWorked] [int] NULL,
		[UserID] [int] NULL,
		[Description] [nvarchar](max) NULL,
		[Notes] [nvarchar](max) NULL,
		[Headers] [nvarchar](max) NULL,
		[MailFrom] [nvarchar](max) NULL,
		[MailTo] [nvarchar](max) NULL,
		[MailCc] [nvarchar](max) NULL,
		[MailBcc] [nvarchar](max) NULL,
		[Subject] [nvarchar](max) NULL,
		[ResUserID] [int] NULL,
		[SendMail] [bit] NULL,
		[IsUnRead] [bit] NULL,
		[Flag] [int] NULL,
		[SysReplication] [int] NULL,
		[GeoLocation] [nvarchar](1000) NULL,
		[Timestamp] [timestamp] NOT NULL,
	 CONSTRAINT [PK_tbl_CallAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_CallAudit to tbl_CallAudit_New
PRINT 'Copy rows from tbl_CallAudit to tbl_CallAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_CallAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_CallAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_CallAudit_New]  WITH (TABLOCK) 
			([ActionCount]
           ,[CallID]
           ,[LinkID]
           ,[SiteID]
           ,[ActionID]
           ,[ActionDate]
           ,[PerformedOn]
           ,[TimeWorked]
           ,[UserID]
           ,[Description]
           ,[Notes]
           ,[Headers]
           ,[MailFrom]
           ,[MailTo]
           ,[MailCc]
           ,[MailBcc]
           ,[Subject]
           ,[ResUserID]
           ,[SendMail]
           ,[IsUnRead]
           ,[Flag]
           ,[SysReplication]
           ,[GeoLocation])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_CallAudit].[ActionCount]
           ,[dbo].[tbl_CallAudit].[CallID]
           ,[dbo].[tbl_CallAudit].[LinkID]
           ,[dbo].[tbl_CallAudit].[SiteID]
           ,[dbo].[tbl_CallAudit].[ActionID]
           ,[dbo].[tbl_CallAudit].[ActionDate]
           ,[dbo].[tbl_CallAudit].[PerformedOn]
           ,[dbo].[tbl_CallAudit].[TimeWorked]
           ,[dbo].[tbl_CallAudit].[UserID]
           ,[dbo].[tbl_CallAudit].[Description]
           ,[dbo].[tbl_CallAudit].[Notes]
           ,[dbo].[tbl_CallAudit].[Headers]
           ,[dbo].[tbl_CallAudit].[MailFrom]
           ,[dbo].[tbl_CallAudit].[MailTo]
           ,[dbo].[tbl_CallAudit].[MailCc]
           ,[dbo].[tbl_CallAudit].[MailBcc]
           ,[dbo].[tbl_CallAudit].[Subject]
           ,[dbo].[tbl_CallAudit].[ResUserID]
           ,[dbo].[tbl_CallAudit].[SendMail]
           ,[dbo].[tbl_CallAudit].[IsUnRead]
           ,[dbo].[tbl_CallAudit].[Flag]
           ,[dbo].[tbl_CallAudit].[SysReplication]
           ,[dbo].[tbl_CallAudit].[GeoLocation] FROM [dbo].[tbl_CallAudit]
		LEFT OUTER JOIN [dbo].[tbl_CallAudit_New] ON [dbo].[tbl_CallAudit_New].[ActionCount] = [dbo].[tbl_CallAudit].[ActionCount] 
		WHERE [dbo].[tbl_CallAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_CallAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_CallAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_CallAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_CallAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_CallAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_CallAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_CallAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_CallAudit]

		SET @PrintMsg = 'Rename name new table tbl_CallAudit_New to tbl_CallAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAudit_New', 'tbl_CallAudit'

		SET @PrintMsg = 'Rename PK_tbl_CallAudit_New Constraints to PK_tbl_CallAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAudit.PK_tbl_CallAudit_New', 'PK_tbl_CallAudit', 'INDEX'

	END
END


-- Create new table tbl_CallAuditAttach_New with correct structure
PRINT 'Create new table tbl_CallAuditAttach_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_CallAuditAttach]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_CallAuditAttach' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_CallAuditAttach_New] (
		[CallID] [int] NULL,
		[ActionCount] [int] NOT NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_CallAuditAttach_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC,
		[SeqNum] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_CallAuditAttach to tbl_CallAuditAttach_New
PRINT 'Copy rows from tbl_CallAuditAttach to tbl_CallAuditAttach_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_CallAuditAttach_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_CallAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_CallAuditAttach_New]  WITH (TABLOCK) 
			([CallID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_CallAuditAttach].[CallID]
           ,[dbo].[tbl_CallAuditAttach].[ActionCount]
           ,[dbo].[tbl_CallAuditAttach].[SeqNum]
           ,[dbo].[tbl_CallAuditAttach].[Filename]
           ,[dbo].[tbl_CallAuditAttach].[FileSize]
           ,[dbo].[tbl_CallAuditAttach].[FileObject]
           ,[dbo].[tbl_CallAuditAttach].[UpdateGUID]
           ,[dbo].[tbl_CallAuditAttach].[SiteID]
           ,[dbo].[tbl_CallAuditAttach].[SysReplication] FROM [dbo].[tbl_CallAuditAttach]
		LEFT OUTER JOIN [dbo].[tbl_CallAuditAttach_New] ON [dbo].[tbl_CallAuditAttach_New].[ActionCount] = [dbo].[tbl_CallAuditAttach].[ActionCount] AND [dbo].[tbl_CallAuditAttach_New].[SeqNum] = [dbo].[tbl_CallAuditAttach].[SeqNum] 
		WHERE [dbo].[tbl_CallAuditAttach_New].[ActionCount] IS NULL AND [dbo].[tbl_CallAuditAttach_New].[SeqNum] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_CallAuditAttach_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_CallAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_CallAuditAttach]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_CallAuditAttach_New]

	SET @PrintMsg = 'Count [dbo].[tbl_CallAuditAttach]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_CallAuditAttach_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_CallAuditAttach]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_CallAuditAttach]

		SET @PrintMsg = 'Rename name new table tbl_CallAuditAttach_New to tbl_CallAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAuditAttach_New', 'tbl_CallAuditAttach'

		SET @PrintMsg = 'Rename PK_tbl_CallAuditAttach_New Constraints to PK_tbl_CallAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAuditAttach.PK_tbl_CallAuditAttach_New', 'PK_tbl_CallAuditAttach', 'INDEX'

	END
END

-- Create new table tbl_CallAuditAttachTemp_New with correct structure
PRINT 'Create new table tbl_CallAuditAttachTemp_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_CallAuditAttachTemp]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_CallAuditAttachTemp' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_CallAuditAttachTemp_New] (
		[TempGUID] [uniqueidentifier] NOT NULL,
		[CallID] [int] NULL,
		[ActionCount] [int] NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_CallAuditAttachTemp_New] PRIMARY KEY CLUSTERED 
	(
		[TempGUID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_CallAuditAttachTemp to tbl_CallAuditAttachTemp_New
PRINT 'Copy rows from tbl_CallAuditAttachTemp to tbl_CallAuditAttachTemp_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_CallAuditAttachTemp_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime
	
	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_CallAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		SET @PrintMsg = 'About to Start Batch ' +  CAST(@BatchCounter As varchar) + '. at ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		INSERT INTO [dbo].[tbl_CallAuditAttachTemp_New]  WITH (TABLOCK) 
			([TempGUID]
           ,[CallID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_CallAuditAttachTemp].[TempGUID]
           ,[dbo].[tbl_CallAuditAttachTemp].[CallID]
           ,[dbo].[tbl_CallAuditAttachTemp].[ActionCount]
           ,[dbo].[tbl_CallAuditAttachTemp].[SeqNum]
           ,[dbo].[tbl_CallAuditAttachTemp].[Filename]
           ,[dbo].[tbl_CallAuditAttachTemp].[FileSize]
           ,[dbo].[tbl_CallAuditAttachTemp].[FileObject]
           ,[dbo].[tbl_CallAuditAttachTemp].[UpdateGUID]
           ,[dbo].[tbl_CallAuditAttachTemp].[SiteID]
           ,[dbo].[tbl_CallAuditAttachTemp].[SysReplication] FROM [dbo].[tbl_CallAuditAttachTemp] 
		LEFT OUTER JOIN [dbo].[tbl_CallAuditAttachTemp_New] ON [dbo].[tbl_CallAuditAttachTemp_New].[TempGUID] = [dbo].[tbl_CallAuditAttachTemp].[TempGUID] 
		WHERE [dbo].[tbl_CallAuditAttachTemp_New].[TempGUID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_CallAuditAttachTemp_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_CallAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT([TempGUID]) FROM [dbo].[tbl_CallAuditAttachTemp]
	SELECT @NewCount = COUNT([TempGUID]) FROM [dbo].[tbl_CallAuditAttachTemp_New]

	SET @PrintMsg = 'Count [dbo].[tbl_CallAuditAttachTemp]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_CallAuditAttachTemp_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_CallAuditAttachTemp]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_CallAuditAttachTemp]

		SET @PrintMsg = 'Rename name new table tbl_CallAuditAttachTemp_New to tbl_CallAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAuditAttachTemp_New', 'tbl_CallAuditAttachTemp'

		SET @PrintMsg = 'Rename PK_tbl_CallAuditAttachTemp_New Constraints to PK_tbl_CallAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_CallAuditAttachTemp.PK_tbl_CallAuditAttachTemp_New', 'PK_tbl_CallAuditAttachTemp', 'INDEX'

	END
END

-- Set Recovery Mode back to "RECOVERY FULL"
PRINT 'Set Recovery Mode back to "RECOVERY FULL"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY FULL
GO

PRINT 'End Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO
