/* ------------------------------------------------------------

Description: Schema synchronization script for object(s)

    fulltext catalogs:
        [Call Search], [Change Request Search], [Problem Search], [Task Search]

    Full Text Catalog Creation for versaSRS v7.0

   AUTHOR:	VersaDev Pty Ltd

   DATE:	15/08/2017 5:39:08 PM

   LEGAL:	 2017 VersaDev Pty Ltd.

   ------------------------------------------------------------ */

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

PRINT 'Start Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

-- Create fulltext catalog [Change Request Search]
Print 'Create fulltext catalog [Change Request Search]'
GO
IF NOT (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Change Request Search'))
CREATE FULLTEXT CATALOG [Change Request Search]
	WITH ACCENT_SENSITIVITY = ON
	AUTHORIZATION [dbo]
GO

-- Create fulltext index on [Change Request Search]
Print 'Create fulltext index on [Change Request Search]'
CREATE FULLTEXT INDEX ON [dbo].[tbl_ChangeRequestAudit] (
	[Description], 
	[Notes], 
	[MailFrom], 
	[MailTo], 
	[MailCc],
	[MailBcc],
	[Subject]
) KEY INDEX PK_tbl_ChangeRequestAudit
	ON [Change Request Search]
GO


-- Create fulltext catalog [Problem Search]
Print 'Create fulltext catalog [Problem Search]'
GO
IF NOT (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Problem Search'))
CREATE FULLTEXT CATALOG [Problem Search]
	WITH ACCENT_SENSITIVITY = ON
	AUTHORIZATION [dbo]
GO

-- Create fulltext index on [Problem Search]
Print 'Create fulltext index on [Problem Search]'
CREATE FULLTEXT INDEX ON [dbo].[tbl_ProblemAudit] (
	[Description], 
	[Notes], 
	[MailFrom], 
	[MailTo], 
	[MailCc],
	[MailBcc],
	[Subject]
) KEY INDEX PK_tbl_ProblemAudit
	ON [Problem Search]
GO


-- Create fulltext catalog [Task Search]
Print 'Create fulltext catalog [Task Search]'
GO
IF NOT (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Task Search'))
CREATE FULLTEXT CATALOG [Task Search]
	WITH ACCENT_SENSITIVITY = ON
	AUTHORIZATION [dbo]
GO

-- Create fulltext index on [Task Search]
Print 'Create fulltext index on [Task Search]'
CREATE FULLTEXT INDEX ON [dbo].[tbl_ActionAudit] (
	[Description], 
	[Notes], 
	[MailFrom], 
	[MailTo], 
	[MailCc],
	[MailBcc],
	[Subject]
) KEY INDEX PK_tbl_ActionAudit
	ON [Task Search]
GO


-- Create fulltext catalog [Call Search]
Print 'Create fulltext catalog [Call Search]'
GO
IF NOT (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Call Search'))
CREATE FULLTEXT CATALOG [Call Search]
	WITH ACCENT_SENSITIVITY = ON
	AUTHORIZATION [dbo]
GO

-- Create fulltext index on [Call Search]
Print 'Create fulltext index on [Call Search]'
CREATE FULLTEXT INDEX ON [dbo].[tbl_CallAudit] (
	[Description], 
	[Notes], 
	[MailFrom], 
	[MailTo], 
	[MailCc],
	[MailBcc],
	[Subject]
) KEY INDEX PK_tbl_CallAudit
	ON [Call Search]
GO



PRINT 'End Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

SET NOEXEC OFF
GO
