-- Alter ntext to nvarchar(max) 
-- tbl_ChangeRequestBilling
-- tbl_ChangeRequestBillingAudit
-- tbl_ChangeRequest
-- tbl_ChangeRequestAudit
-- tbl_ChangeRequestAuditAttach
-- tbl_ChangeRequestAuditAttachTemp

/*
So if we need use T-SQL to move data from one place to another one. It is recommended to use TABLOCK option on the destination table. With a few other constraints, the query can be executed with minimal logging.

The few constraints are:

The database must be in bulk logged recovery model.
The destination table must be empty or without clustered index.
There is no non-clustered index on the destination table.
*/

-- WITH (TABLOCK)
-- The above statement used in INSERT INTO statement will execute with minimal logging, hence improve execution time.
-- To enable "TABLOCK", the database must be in BULK_LOGGED or SIMPLE Recovery mode.

-- Set Recovery Mode to "SIMPLE"
PRINT 'Set Recovery Mode to "SIMPLE"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY SIMPLE
GO

Use [versaSRS]
GO

PRINT 'Start Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

-- Drop FullText index on [dbo].[tbl_ChangeRequestAudit]
Print 'Drop FullText index on [dbo].[tbl_ChangeRequestAudit]'
GO
IF (EXISTS(SELECT * FROM sys.objects o inner join sys.fulltext_indexes fi on fi.object_id = o.object_id WHERE o.[object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestAudit]') AND [type]='U'))
	DROP FULLTEXT INDEX ON [dbo].[tbl_ChangeRequestAudit]
GO

-- Drop fulltext catalog [Change Request Search]
Print 'Drop fulltext catalog [Change Request Search]'
GO
IF (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Change Request Search'))
	DROP FULLTEXT CATALOG [Change Request Search]
GO

-- Create new table tbl_ChangeRequestBilling_New with correct structure
PRINT 'Create new table tbl_ChangeRequestBilling_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestBilling]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ChangeRequestBilling' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ChangeRequestBilling_New] (
			[ChangeRequestID]     [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ChangeRequestBilling_New] PRIMARY KEY CLUSTERED 
	(
		[ChangeRequestID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ChangeRequestBilling to tbl_ChangeRequestBilling_New
PRINT 'Copy rows from tbl_ChangeRequestBilling to tbl_ChangeRequestBilling_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequestBilling_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequestBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequestBilling_New] WITH (TABLOCK) 
			   ([ChangeRequestID]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ChangeRequestBilling].[ChangeRequestID]
			   ,[dbo].[tbl_ChangeRequestBilling].[SiteID]
			   ,[dbo].[tbl_ChangeRequestBilling].[NumTransactions]
			   ,[dbo].[tbl_ChangeRequestBilling].[CumulativeTime]
			   ,[dbo].[tbl_ChangeRequestBilling].[EstimatedTime]
			   ,[dbo].[tbl_ChangeRequestBilling].[Charge]
			   ,[dbo].[tbl_ChangeRequestBilling].[ChargeType]
			   ,[dbo].[tbl_ChangeRequestBilling].[ChargeCompany]
			   ,[dbo].[tbl_ChangeRequestBilling].[BilledTo]
			   ,[dbo].[tbl_ChangeRequestBilling].[SLA]
			   ,[dbo].[tbl_ChangeRequestBilling].[Quote]
			   ,[dbo].[tbl_ChangeRequestBilling].[RefNum]
			   ,[dbo].[tbl_ChangeRequestBilling].[Notes]
			   ,[dbo].[tbl_ChangeRequestBilling].[SysReplication] FROM [dbo].[tbl_ChangeRequestBilling]
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequestBilling_New] ON [dbo].[tbl_ChangeRequestBilling_New].[ChangeRequestID] = [dbo].[tbl_ChangeRequestBilling].[ChangeRequestID] 
		WHERE [dbo].[tbl_ChangeRequestBilling_New].[ChangeRequestID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequestBilling_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequestBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ChangeRequestID) FROM [dbo].[tbl_ChangeRequestBilling]
	SELECT @NewCount = COUNT(ChangeRequestID) FROM [dbo].[tbl_ChangeRequestBilling_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestBilling]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestBilling_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequestBilling]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequestBilling]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequestBilling_New to tbl_ChangeRequestBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestBilling_New', 'tbl_ChangeRequestBilling'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequestBilling_New Constraints to PK_tbl_ChangeRequestBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestBilling.PK_tbl_ChangeRequestBilling_New', 'PK_tbl_ChangeRequestBilling', 'INDEX'

	END
END

-- Create new table tbl_ChangeRequestBillingAudit_New with correct structure
PRINT 'Create new table tbl_ChangeRequestBillingAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestBillingAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ChangeRequestBillingAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ChangeRequestBillingAudit_New] (
			[ActionCount]         [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[BilledTime]          [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ChangeRequestBillingAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO


-- Copy rows from tbl_ChangeRequestBillingAudit to tbl_ChangeRequestBillingAudit_New
PRINT 'Copy rows from tbl_ChangeRequestBillingAudit to tbl_ChangeRequestBillingAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequestBillingAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequestBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequestBillingAudit_New]  WITH (TABLOCK) 
			   ([ActionCount]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[BilledTime]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ChangeRequestBillingAudit].[ActionCount]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[SiteID]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[NumTransactions]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[BilledTime]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[CumulativeTime]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[EstimatedTime]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[Charge]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[ChargeType]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[ChargeCompany]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[BilledTo]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[SLA]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[Quote]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[RefNum]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[Notes]
			   ,[dbo].[tbl_ChangeRequestBillingAudit].[SysReplication] FROM [dbo].[tbl_ChangeRequestBillingAudit]
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequestBillingAudit_New] ON [dbo].[tbl_ChangeRequestBillingAudit_New].[ActionCount] = [dbo].[tbl_ChangeRequestBillingAudit].[ActionCount] 
		WHERE [dbo].[tbl_ChangeRequestBillingAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequestBillingAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequestBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestBillingAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestBillingAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestBillingAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestBillingAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequestBillingAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequestBillingAudit]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequestBillingAudit_New to tbl_ChangeRequestBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestBillingAudit_New', 'tbl_ChangeRequestBillingAudit'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequestBillingAudit_New Constraints to PK_tbl_ChangeRequestBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestBillingAudit.PK_tbl_ChangeRequestBillingAudit_New', 'PK_tbl_ChangeRequestBillingAudit', 'INDEX'

	END
END

-- Create new table tbl_ChangeRequests_New with correct structure
PRINT 'Create new table tbl_ChangeRequests_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequests]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Description' AND TABLE_NAME= 'tbl_ChangeRequests' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ChangeRequests_New] (
		[ChangeRequestID] [int] NOT NULL,
		[ChangeRequestPID] [int] NULL,
		[SiteID] [int] NULL,
		[HDUserID] [int] NULL,
		[DateEntered] [datetime] NULL,
		[LastUpdated] [datetime] NULL,
		[Closed] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[ResUserID] [int] NULL,
		[ClosureTypeID] [int] NULL,
		[DateStarted] [datetime] NULL,
		[ElapsedTime] [int] NULL,
		[ChangeRequestTypeID] [int] NULL,
		[ReceivedByID] [int] NULL,
		[ChangeRequestStatusID] [int] NULL,
		[StageID] [int] NULL,
		[ApprovalStatusID] [int] NULL,
		[Subject] [nvarchar](500) NULL,
		[Description] [nvarchar](max) NULL,
		[PostImplementationReview] [nvarchar](max) NULL,
		[HotNewsID] [int] NULL,
		[PriorityID] [int] NULL,
		[UrgencyID] [int] NULL,
		[RiskID] [int] NULL,
		[ServiceAreaID] [int] NULL,
		[Key1] [int] NULL,
		[Key2] [int] NULL,
		[Key3] [int] NULL,
		[ProductTypeID] [int] NULL,
		[ProductID] [int] NULL,
		[ImpactID] [int] NULL,
		[SymptomCodeID] [int] NULL,
		[CauseCodeID] [int] NULL,
		[DueDate] [datetime] NULL,
		[QueueID] [int] NULL,
		[GroupID] [int] NULL,
		[UserID] [int] NULL,
		[EstSolDate] [datetime] NULL,
		[Notification] [int] NULL,
		[EmailNotification] [bit] NULL,
		[CompanyName] [nvarchar](250) NULL,
		[CompanyID] [int] NULL,
		[ContactID] [int] NULL,
		[CompanyIDGUID] [varchar](100) NULL,
		[ContactIDGUID] [varchar](100) NULL,
		[FirstName] [nvarchar](100) NULL,
		[LastName] [nvarchar](100) NULL,
		[Email] [nvarchar](100) NULL,
		[Username] [nvarchar](200) NULL,
		[Phone] [nvarchar](100) NULL,
		[Division] [nvarchar](200) NULL,
		[Department] [nvarchar](200) NULL,
		[Location] [nvarchar](200) NULL,
		[Computer] [nvarchar](200) NULL,
		[ReqCompanyName] [nvarchar](250) NULL,
		[ReqCompanyID] [int] NULL,
		[ReqContactID] [int] NULL,
		[ReqCompanyIDGUID] [varchar](100) NULL,
		[ReqContactIDGUID] [varchar](100) NULL,
		[ReqFirstName] [nvarchar](100) NULL,
		[ReqLastName] [nvarchar](100) NULL,
		[ReqEmail] [nvarchar](100) NULL,
		[ReqUsername] [nvarchar](200) NULL,
		[ReqPhone] [nvarchar](100) NULL,
		[ReqDivision] [nvarchar](200) NULL,
		[ReqDepartment] [nvarchar](200) NULL,
		[ReqLocation] [nvarchar](200) NULL,
		[ReqComputer] [nvarchar](200) NULL,
		[PlanStart] [datetime] NULL,
		[PlanEnd] [datetime] NULL,
		[ActualStart] [datetime] NULL,
		[ActualEnd] [datetime] NULL,
		[EstimatedTime] [int] NULL,
		[ActualTime] [int] NULL,
		[EstimatedCost] [money] NULL,
		[ActualCost] [money] NULL,
		[BusinessImpactAnalysis] [nvarchar](max) NULL,
		[BusinessProductivityLoss] [nvarchar](250) NULL,
		[TechnicalResources] [nvarchar](max) NULL,
		[JustificationCodeID] [int] NULL,
		[Justification] [nvarchar](max) NULL,
		[DueDateNotification] [bit] NULL,
		[EstSolDateNotification] [bit] NULL,
		[OpenNotificationOnLog] [bit] NULL,
		[PolicyID] [int] NULL,
		[PolicyName] [nvarchar](255) NULL,
		[PolicyType] [int] NULL,
		[PolicyDecisionDueDate] [datetime] NULL,
		[PolicyDecisionCompletedDate] [datetime] NULL,
		[MinNumApprovers] [int] NULL,
		[SysReplication] [int] NULL,
		[ChangeRequestLocked] [int] NULL,
		[ArchiveID] [int] NULL,
		[ArchiveDate] [datetime] NULL,
		[JobTitle] [nvarchar](200) NULL,
		[ReqJobTitle] [nvarchar](200) NULL,
	 CONSTRAINT [PK_tbl_ChangeRequests_New] PRIMARY KEY CLUSTERED 
	(
		[ChangeRequestID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ChangeRequests to tbl_ChangeRequests_New
PRINT 'Copy rows from tbl_ChangeRequests to tbl_ChangeRequests_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequests_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequests_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequests_New]  WITH (TABLOCK) 
			   ([ChangeRequestID]
			   ,[ChangeRequestPID]
			   ,[SiteID]
			   ,[HDUserID]
			   ,[DateEntered]
			   ,[LastUpdated]
			   ,[Closed]
			   ,[PerformedOn]
			   ,[ResUserID]
			   ,[ClosureTypeID]
			   ,[DateStarted]
			   ,[ElapsedTime]
			   ,[ChangeRequestTypeID]
			   ,[ReceivedByID]
			   ,[ChangeRequestStatusID]
			   ,[StageID]
			   ,[ApprovalStatusID]
			   ,[Subject]
			   ,[Description]
			   ,[PostImplementationReview]
			   ,[HotNewsID]
			   ,[PriorityID]
			   ,[UrgencyID]
			   ,[RiskID]
			   ,[ServiceAreaID]
			   ,[Key1]
			   ,[Key2]
			   ,[Key3]
			   ,[ProductTypeID]
			   ,[ProductID]
			   ,[ImpactID]
			   ,[SymptomCodeID]
			   ,[CauseCodeID]
			   ,[DueDate]
			   ,[QueueID]
			   ,[GroupID]
			   ,[UserID]
			   ,[EstSolDate]
			   ,[Notification]
			   ,[EmailNotification]
			   ,[CompanyName]
			   ,[CompanyID]
			   ,[ContactID]
			   ,[CompanyIDGUID]
			   ,[ContactIDGUID]
			   ,[FirstName]
			   ,[LastName]
			   ,[Email]
			   ,[Username]
			   ,[Phone]
			   ,[Division]
			   ,[Department]
			   ,[Location]
			   ,[Computer]
			   ,[ReqCompanyName]
			   ,[ReqCompanyID]
			   ,[ReqContactID]
			   ,[ReqCompanyIDGUID]
			   ,[ReqContactIDGUID]
			   ,[ReqFirstName]
			   ,[ReqLastName]
			   ,[ReqEmail]
			   ,[ReqUsername]
			   ,[ReqPhone]
			   ,[ReqDivision]
			   ,[ReqDepartment]
			   ,[ReqLocation]
			   ,[ReqComputer]
			   ,[PlanStart]
			   ,[PlanEnd]
			   ,[ActualStart]
			   ,[ActualEnd]
			   ,[EstimatedTime]
			   ,[ActualTime]
			   ,[EstimatedCost]
			   ,[ActualCost]
			   ,[BusinessImpactAnalysis]
			   ,[BusinessProductivityLoss]
			   ,[TechnicalResources]
			   ,[JustificationCodeID]
			   ,[Justification]
			   ,[DueDateNotification]
			   ,[EstSolDateNotification]
			   ,[OpenNotificationOnLog]
			   ,[PolicyID]
			   ,[PolicyName]
			   ,[PolicyType]
			   ,[PolicyDecisionDueDate]
			   ,[PolicyDecisionCompletedDate]
			   ,[MinNumApprovers]
			   ,[SysReplication]
			   ,[ChangeRequestLocked]
			   ,[ArchiveID]
			   ,[ArchiveDate]
			   ,[JobTitle]
			   ,[ReqJobTitle])
		SELECT TOP (@BatchVolume)
			    [dbo].[tbl_ChangeRequests].[ChangeRequestID]
			   ,[dbo].[tbl_ChangeRequests].[ChangeRequestPID]
			   ,[dbo].[tbl_ChangeRequests].[SiteID]
			   ,[dbo].[tbl_ChangeRequests].[HDUserID]
			   ,[dbo].[tbl_ChangeRequests].[DateEntered]
			   ,[dbo].[tbl_ChangeRequests].[LastUpdated]
			   ,[dbo].[tbl_ChangeRequests].[Closed]
			   ,[dbo].[tbl_ChangeRequests].[PerformedOn]
			   ,[dbo].[tbl_ChangeRequests].[ResUserID]
			   ,[dbo].[tbl_ChangeRequests].[ClosureTypeID]
			   ,[dbo].[tbl_ChangeRequests].[DateStarted]
			   ,[dbo].[tbl_ChangeRequests].[ElapsedTime]
			   ,[dbo].[tbl_ChangeRequests].[ChangeRequestTypeID]
			   ,[dbo].[tbl_ChangeRequests].[ReceivedByID]
			   ,[dbo].[tbl_ChangeRequests].[ChangeRequestStatusID]
			   ,[dbo].[tbl_ChangeRequests].[StageID]
			   ,[dbo].[tbl_ChangeRequests].[ApprovalStatusID]
			   ,[dbo].[tbl_ChangeRequests].[Subject]
			   ,[dbo].[tbl_ChangeRequests].[Description]
			   ,[dbo].[tbl_ChangeRequests].[PostImplementationReview]
			   ,[dbo].[tbl_ChangeRequests].[HotNewsID]
			   ,[dbo].[tbl_ChangeRequests].[PriorityID]
			   ,[dbo].[tbl_ChangeRequests].[UrgencyID]
			   ,[dbo].[tbl_ChangeRequests].[RiskID]
			   ,[dbo].[tbl_ChangeRequests].[ServiceAreaID]
			   ,[dbo].[tbl_ChangeRequests].[Key1]
			   ,[dbo].[tbl_ChangeRequests].[Key2]
			   ,[dbo].[tbl_ChangeRequests].[Key3]
			   ,[dbo].[tbl_ChangeRequests].[ProductTypeID]
			   ,[dbo].[tbl_ChangeRequests].[ProductID]
			   ,[dbo].[tbl_ChangeRequests].[ImpactID]
			   ,[dbo].[tbl_ChangeRequests].[SymptomCodeID]
			   ,[dbo].[tbl_ChangeRequests].[CauseCodeID]
			   ,[dbo].[tbl_ChangeRequests].[DueDate]
			   ,[dbo].[tbl_ChangeRequests].[QueueID]
			   ,[dbo].[tbl_ChangeRequests].[GroupID]
			   ,[dbo].[tbl_ChangeRequests].[UserID]
			   ,[dbo].[tbl_ChangeRequests].[EstSolDate]
			   ,[dbo].[tbl_ChangeRequests].[Notification]
			   ,[dbo].[tbl_ChangeRequests].[EmailNotification]
			   ,[dbo].[tbl_ChangeRequests].[CompanyName]
			   ,[dbo].[tbl_ChangeRequests].[CompanyID]
			   ,[dbo].[tbl_ChangeRequests].[ContactID]
			   ,[dbo].[tbl_ChangeRequests].[CompanyIDGUID]
			   ,[dbo].[tbl_ChangeRequests].[ContactIDGUID]
			   ,[dbo].[tbl_ChangeRequests].[FirstName]
			   ,[dbo].[tbl_ChangeRequests].[LastName]
			   ,[dbo].[tbl_ChangeRequests].[Email]
			   ,[dbo].[tbl_ChangeRequests].[Username]
			   ,[dbo].[tbl_ChangeRequests].[Phone]
			   ,[dbo].[tbl_ChangeRequests].[Division]
			   ,[dbo].[tbl_ChangeRequests].[Department]
			   ,[dbo].[tbl_ChangeRequests].[Location]
			   ,[dbo].[tbl_ChangeRequests].[Computer]
			   ,[dbo].[tbl_ChangeRequests].[ReqCompanyName]
			   ,[dbo].[tbl_ChangeRequests].[ReqCompanyID]
			   ,[dbo].[tbl_ChangeRequests].[ReqContactID]
			   ,[dbo].[tbl_ChangeRequests].[ReqCompanyIDGUID]
			   ,[dbo].[tbl_ChangeRequests].[ReqContactIDGUID]
			   ,[dbo].[tbl_ChangeRequests].[ReqFirstName]
			   ,[dbo].[tbl_ChangeRequests].[ReqLastName]
			   ,[dbo].[tbl_ChangeRequests].[ReqEmail]
			   ,[dbo].[tbl_ChangeRequests].[ReqUsername]
			   ,[dbo].[tbl_ChangeRequests].[ReqPhone]
			   ,[dbo].[tbl_ChangeRequests].[ReqDivision]
			   ,[dbo].[tbl_ChangeRequests].[ReqDepartment]
			   ,[dbo].[tbl_ChangeRequests].[ReqLocation]
			   ,[dbo].[tbl_ChangeRequests].[ReqComputer]
			   ,[dbo].[tbl_ChangeRequests].[PlanStart]
			   ,[dbo].[tbl_ChangeRequests].[PlanEnd]
			   ,[dbo].[tbl_ChangeRequests].[ActualStart]
			   ,[dbo].[tbl_ChangeRequests].[ActualEnd]
			   ,[dbo].[tbl_ChangeRequests].[EstimatedTime]
			   ,[dbo].[tbl_ChangeRequests].[ActualTime]
			   ,[dbo].[tbl_ChangeRequests].[EstimatedCost]
			   ,[dbo].[tbl_ChangeRequests].[ActualCost]
			   ,[dbo].[tbl_ChangeRequests].[BusinessImpactAnalysis]
			   ,[dbo].[tbl_ChangeRequests].[BusinessProductivityLoss]
			   ,[dbo].[tbl_ChangeRequests].[TechnicalResources]
			   ,[dbo].[tbl_ChangeRequests].[JustificationCodeID]
			   ,[dbo].[tbl_ChangeRequests].[Justification]
			   ,[dbo].[tbl_ChangeRequests].[DueDateNotification]
			   ,[dbo].[tbl_ChangeRequests].[EstSolDateNotification]
			   ,[dbo].[tbl_ChangeRequests].[OpenNotificationOnLog]
			   ,[dbo].[tbl_ChangeRequests].[PolicyID]
			   ,[dbo].[tbl_ChangeRequests].[PolicyName]
			   ,[dbo].[tbl_ChangeRequests].[PolicyType]
			   ,[dbo].[tbl_ChangeRequests].[PolicyDecisionDueDate]
			   ,[dbo].[tbl_ChangeRequests].[PolicyDecisionCompletedDate]
			   ,[dbo].[tbl_ChangeRequests].[MinNumApprovers]
			   ,[dbo].[tbl_ChangeRequests].[SysReplication]
			   ,[dbo].[tbl_ChangeRequests].[ChangeRequestLocked]
			   ,[dbo].[tbl_ChangeRequests].[ArchiveID]
			   ,[dbo].[tbl_ChangeRequests].[ArchiveDate]
			   ,[dbo].[tbl_ChangeRequests].[JobTitle]
			   ,[dbo].[tbl_ChangeRequests].[ReqJobTitle] FROM [dbo].[tbl_ChangeRequests]
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequests_New] ON [dbo].[tbl_ChangeRequests_New].[ChangeRequestID] = [dbo].[tbl_ChangeRequests].[ChangeRequestID] 
		WHERE [dbo].[tbl_ChangeRequests_New].[ChangeRequestID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequests_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequests_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ChangeRequestID) FROM [dbo].[tbl_ChangeRequests]
	SELECT @NewCount = COUNT(ChangeRequestID) FROM [dbo].[tbl_ChangeRequests_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequests]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequests_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequests]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequests]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequests_New to tbl_ChangeRequests'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequests_New', 'tbl_ChangeRequests'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequests_New Constraints to PK_tbl_ChangeRequests'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequests.PK_tbl_ChangeRequests_New', 'PK_tbl_ChangeRequests', 'INDEX'

	END
END

-- Create new table tbl_ChangeRequestAudit_New with correct structure
PRINT 'Create new table tbl_ChangeRequestAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ChangeRequestAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ChangeRequestAudit_New] (
		[ActionCount] [int] NOT NULL,
		[ChangeRequestID] [int] NULL,
		[LinkID] [int] NULL,
		[SiteID] [int] NULL,
		[ActionID] [int] NULL,
		[ActionDate] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[TimeWorked] [int] NULL,
		[UserID] [int] NULL,
		[Description] [nvarchar](max) NULL,
		[Notes] [nvarchar](max) NULL,
		[Headers] [nvarchar](max) NULL,
		[MailFrom] [nvarchar](max) NULL,
		[MailTo] [nvarchar](max) NULL,
		[MailCc] [nvarchar](max) NULL,
		[MailBcc] [nvarchar](max) NULL,
		[Subject] [nvarchar](max) NULL,
		[ResUserID] [int] NULL,
		[SendMail] [bit] NULL,
		[IsUnRead] [bit] NULL,
		[Flag] [int] NULL,
		[SysReplication] [int] NULL,
		[GeoLocation] [nvarchar](1000) NULL,
		[Timestamp] [timestamp] NOT NULL,
	 CONSTRAINT [PK_tbl_ChangeRequestAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ChangeRequestAudit to tbl_ChangeRequestAudit_New
PRINT 'Copy rows from tbl_ChangeRequestAudit to tbl_ChangeRequestAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequestAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequestAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequestAudit_New]  WITH (TABLOCK) 
			([ActionCount]
           ,[ChangeRequestID]
           ,[LinkID]
           ,[SiteID]
           ,[ActionID]
           ,[ActionDate]
           ,[PerformedOn]
           ,[TimeWorked]
           ,[UserID]
           ,[Description]
           ,[Notes]
           ,[Headers]
           ,[MailFrom]
           ,[MailTo]
           ,[MailCc]
           ,[MailBcc]
           ,[Subject]
           ,[ResUserID]
           ,[SendMail]
           ,[IsUnRead]
           ,[Flag]
           ,[SysReplication]
           ,[GeoLocation])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ChangeRequestAudit].[ActionCount]
           ,[dbo].[tbl_ChangeRequestAudit].[ChangeRequestID]
           ,[dbo].[tbl_ChangeRequestAudit].[LinkID]
           ,[dbo].[tbl_ChangeRequestAudit].[SiteID]
           ,[dbo].[tbl_ChangeRequestAudit].[ActionID]
           ,[dbo].[tbl_ChangeRequestAudit].[ActionDate]
           ,[dbo].[tbl_ChangeRequestAudit].[PerformedOn]
           ,[dbo].[tbl_ChangeRequestAudit].[TimeWorked]
           ,[dbo].[tbl_ChangeRequestAudit].[UserID]
           ,[dbo].[tbl_ChangeRequestAudit].[Description]
           ,[dbo].[tbl_ChangeRequestAudit].[Notes]
           ,[dbo].[tbl_ChangeRequestAudit].[Headers]
           ,[dbo].[tbl_ChangeRequestAudit].[MailFrom]
           ,[dbo].[tbl_ChangeRequestAudit].[MailTo]
           ,[dbo].[tbl_ChangeRequestAudit].[MailCc]
           ,[dbo].[tbl_ChangeRequestAudit].[MailBcc]
           ,[dbo].[tbl_ChangeRequestAudit].[Subject]
           ,[dbo].[tbl_ChangeRequestAudit].[ResUserID]
           ,[dbo].[tbl_ChangeRequestAudit].[SendMail]
           ,[dbo].[tbl_ChangeRequestAudit].[IsUnRead]
           ,[dbo].[tbl_ChangeRequestAudit].[Flag]
           ,[dbo].[tbl_ChangeRequestAudit].[SysReplication]
           ,[dbo].[tbl_ChangeRequestAudit].[GeoLocation] FROM [dbo].[tbl_ChangeRequestAudit]
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequestAudit_New] ON [dbo].[tbl_ChangeRequestAudit_New].[ActionCount] = [dbo].[tbl_ChangeRequestAudit].[ActionCount] 
		WHERE [dbo].[tbl_ChangeRequestAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequestAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequestAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequestAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequestAudit]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequestAudit_New to tbl_ChangeRequestAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAudit_New', 'tbl_ChangeRequestAudit'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequestAudit_New Constraints to PK_tbl_ChangeRequestAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAudit.PK_tbl_ChangeRequestAudit_New', 'PK_tbl_ChangeRequestAudit', 'INDEX'

	END
END


-- Create new table tbl_ChangeRequestAuditAttach_New with correct structure
PRINT 'Create new table tbl_ChangeRequestAuditAttach_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestAuditAttach]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ChangeRequestAuditAttach' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ChangeRequestAuditAttach_New] (
		[ChangeRequestID] [int] NULL,
		[ActionCount] [int] NOT NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ChangeRequestAuditAttach_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC,
		[SeqNum] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ChangeRequestAuditAttach to tbl_ChangeRequestAuditAttach_New
PRINT 'Copy rows from tbl_ChangeRequestAuditAttach to tbl_ChangeRequestAuditAttach_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequestAuditAttach_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequestAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequestAuditAttach_New]  WITH (TABLOCK) 
			([ChangeRequestID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ChangeRequestAuditAttach].[ChangeRequestID]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[ActionCount]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[SeqNum]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[Filename]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[FileSize]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[FileObject]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[UpdateGUID]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[SiteID]
           ,[dbo].[tbl_ChangeRequestAuditAttach].[SysReplication] FROM [dbo].[tbl_ChangeRequestAuditAttach]
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequestAuditAttach_New] ON [dbo].[tbl_ChangeRequestAuditAttach_New].[ActionCount] = [dbo].[tbl_ChangeRequestAuditAttach].[ActionCount] AND [dbo].[tbl_ChangeRequestAuditAttach_New].[SeqNum] = [dbo].[tbl_ChangeRequestAuditAttach].[SeqNum] 
		WHERE [dbo].[tbl_ChangeRequestAuditAttach_New].[ActionCount] IS NULL AND [dbo].[tbl_ChangeRequestAuditAttach_New].[SeqNum] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequestAuditAttach_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequestAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestAuditAttach]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ChangeRequestAuditAttach_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAuditAttach]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAuditAttach_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequestAuditAttach]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequestAuditAttach]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequestAuditAttach_New to tbl_ChangeRequestAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAuditAttach_New', 'tbl_ChangeRequestAuditAttach'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequestAuditAttach_New Constraints to PK_tbl_ChangeRequestAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAuditAttach.PK_tbl_ChangeRequestAuditAttach_New', 'PK_tbl_ChangeRequestAuditAttach', 'INDEX'

	END
END

-- Create new table tbl_ChangeRequestAuditAttachTemp_New with correct structure
PRINT 'Create new table tbl_ChangeRequestAuditAttachTemp_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ChangeRequestAuditAttachTemp]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ChangeRequestAuditAttachTemp' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ChangeRequestAuditAttachTemp_New] (
		[TempGUID] [uniqueidentifier] NOT NULL,
		[ChangeRequestID] [int] NULL,
		[ActionCount] [int] NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ChangeRequestAuditAttachTemp_New] PRIMARY KEY CLUSTERED 
	(
		[TempGUID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ChangeRequestAuditAttachTemp to tbl_ChangeRequestAuditAttachTemp_New
PRINT 'Copy rows from tbl_ChangeRequestAuditAttachTemp to tbl_ChangeRequestAuditAttachTemp_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ChangeRequestAuditAttachTemp_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime
	
	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ChangeRequestAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ChangeRequestAuditAttachTemp_New]  WITH (TABLOCK) 
			([TempGUID]
           ,[ChangeRequestID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ChangeRequestAuditAttachTemp].[TempGUID]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[ChangeRequestID]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[ActionCount]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[SeqNum]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[Filename]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[FileSize]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[FileObject]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[UpdateGUID]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[SiteID]
           ,[dbo].[tbl_ChangeRequestAuditAttachTemp].[SysReplication] FROM [dbo].[tbl_ChangeRequestAuditAttachTemp] 
		LEFT OUTER JOIN [dbo].[tbl_ChangeRequestAuditAttachTemp_New] ON [dbo].[tbl_ChangeRequestAuditAttachTemp_New].[TempGUID] = [dbo].[tbl_ChangeRequestAuditAttachTemp].[TempGUID] 
		WHERE [dbo].[tbl_ChangeRequestAuditAttachTemp_New].[TempGUID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ChangeRequestAuditAttachTemp_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ChangeRequestAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT([TempGUID]) FROM [dbo].[tbl_ChangeRequestAuditAttachTemp]
	SELECT @NewCount = COUNT([TempGUID]) FROM [dbo].[tbl_ChangeRequestAuditAttachTemp_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAuditAttachTemp]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ChangeRequestAuditAttachTemp_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ChangeRequestAuditAttachTemp]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ChangeRequestAuditAttachTemp]

		SET @PrintMsg = 'Rename name new table tbl_ChangeRequestAuditAttachTemp_New to tbl_ChangeRequestAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAuditAttachTemp_New', 'tbl_ChangeRequestAuditAttachTemp'

		SET @PrintMsg = 'Rename PK_tbl_ChangeRequestAuditAttachTemp_New Constraints to PK_tbl_ChangeRequestAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ChangeRequestAuditAttachTemp.PK_tbl_ChangeRequestAuditAttachTemp_New', 'PK_tbl_ChangeRequestAuditAttachTemp', 'INDEX'

	END
END

-- Set Recovery Mode back to "RECOVERY FULL"
PRINT 'Set Recovery Mode back to "RECOVERY FULL"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY FULL
GO

PRINT 'End Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO
