-- Alter ntext to nvarchar(max) 
-- tbl_ProblemBilling
-- tbl_ProblemBillingAudit
-- tbl_Problems
-- tbl_ProblemAudit
-- tbl_ProblemAuditAttach
-- tbl_ProblemAuditAttachTemp
/*
So if we need use T-SQL to move data from one place to another one. It is recommended to use TABLOCK option on the destination table. With a few other constraints, the query can be executed with minimal logging.

The few constraints are:

The database must be in bulk logged recovery model.
The destination table must be empty or without clustered index.
There is no non-clustered index on the destination table.
*/

-- WITH (TABLOCK)
-- The above statement used in INSERT INTO statement will execute with minimal logging, hence improve execution time.
-- To enable "TABLOCK", the database must be in BULK_LOGGED or SIMPLE Recovery mode.

-- Set Recovery Mode to "SIMPLE"
PRINT 'Set Recovery Mode to "SIMPLE"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY SIMPLE
GO

Use [versaSRS]
GO

PRINT 'Start Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

-- Drop FullText index on [dbo].[tbl_ProblemAudit]
Print 'Drop FullText index on [dbo].[tbl_ProblemAudit]'
GO
IF (EXISTS(SELECT * FROM sys.objects o inner join sys.fulltext_indexes fi on fi.object_id = o.object_id WHERE o.[object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemAudit]') AND [type]='U'))
	DROP FULLTEXT INDEX ON [dbo].[tbl_ProblemAudit]
GO

-- Drop fulltext catalog [Problem Search]
Print 'Drop fulltext catalog [Problem Search]'
GO
IF (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Problem Search'))
	DROP FULLTEXT CATALOG [Problem Search]
GO

-- Create new table tbl_ProblemBilling_New with correct structure
PRINT 'Create new table tbl_ProblemBilling_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemBilling]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ProblemBilling' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ProblemBilling_New] (
			[ProblemID]              [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ProblemBilling_New] PRIMARY KEY CLUSTERED 
	(
		[ProblemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ProblemBilling to tbl_ProblemBilling_New
PRINT 'Copy rows from tbl_ProblemBilling to tbl_ProblemBilling_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ProblemBilling_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ProblemBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ProblemBilling_New] WITH (TABLOCK) 
			   ([ProblemID]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ProblemBilling].[ProblemID]
			   ,[dbo].[tbl_ProblemBilling].[SiteID]
			   ,[dbo].[tbl_ProblemBilling].[NumTransactions]
			   ,[dbo].[tbl_ProblemBilling].[CumulativeTime]
			   ,[dbo].[tbl_ProblemBilling].[EstimatedTime]
			   ,[dbo].[tbl_ProblemBilling].[Charge]
			   ,[dbo].[tbl_ProblemBilling].[ChargeType]
			   ,[dbo].[tbl_ProblemBilling].[ChargeCompany]
			   ,[dbo].[tbl_ProblemBilling].[BilledTo]
			   ,[dbo].[tbl_ProblemBilling].[SLA]
			   ,[dbo].[tbl_ProblemBilling].[Quote]
			   ,[dbo].[tbl_ProblemBilling].[RefNum]
			   ,[dbo].[tbl_ProblemBilling].[Notes]
			   ,[dbo].[tbl_ProblemBilling].[SysReplication] FROM [dbo].[tbl_ProblemBilling]
		LEFT OUTER JOIN [dbo].[tbl_ProblemBilling_New] ON [dbo].[tbl_ProblemBilling_New].[ProblemID] = [dbo].[tbl_ProblemBilling].[ProblemID] 
		WHERE [dbo].[tbl_ProblemBilling_New].[ProblemID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ProblemBilling_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ProblemBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ProblemID) FROM [dbo].[tbl_ProblemBilling]
	SELECT @NewCount = COUNT(ProblemID) FROM [dbo].[tbl_ProblemBilling_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemBilling]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemBilling_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ProblemBilling]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ProblemBilling]

		SET @PrintMsg = 'Rename name new table tbl_ProblemBilling_New to tbl_ProblemBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemBilling_New', 'tbl_ProblemBilling'

		SET @PrintMsg = 'Rename PK_tbl_ProblemBilling_New Constraints to PK_tbl_ProblemBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemBilling.PK_tbl_ProblemBilling_New', 'PK_tbl_ProblemBilling', 'INDEX'

	END
END

-- Create new table tbl_ProblemBillingAudit_New with correct structure
PRINT 'Create new table tbl_ProblemBillingAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemBillingAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ProblemBillingAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ProblemBillingAudit_New] (
			[ActionCount]         [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[BilledTime]          [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ProblemBillingAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO


-- Copy rows from tbl_ProblemBillingAudit to tbl_ProblemBillingAudit_New
PRINT 'Copy rows from tbl_ProblemBillingAudit to tbl_ProblemBillingAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ProblemBillingAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ProblemBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ProblemBillingAudit_New]  WITH (TABLOCK) 
			   ([ActionCount]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[BilledTime]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ProblemBillingAudit].[ActionCount]
			   ,[dbo].[tbl_ProblemBillingAudit].[SiteID]
			   ,[dbo].[tbl_ProblemBillingAudit].[NumTransactions]
			   ,[dbo].[tbl_ProblemBillingAudit].[BilledTime]
			   ,[dbo].[tbl_ProblemBillingAudit].[CumulativeTime]
			   ,[dbo].[tbl_ProblemBillingAudit].[EstimatedTime]
			   ,[dbo].[tbl_ProblemBillingAudit].[Charge]
			   ,[dbo].[tbl_ProblemBillingAudit].[ChargeType]
			   ,[dbo].[tbl_ProblemBillingAudit].[ChargeCompany]
			   ,[dbo].[tbl_ProblemBillingAudit].[BilledTo]
			   ,[dbo].[tbl_ProblemBillingAudit].[SLA]
			   ,[dbo].[tbl_ProblemBillingAudit].[Quote]
			   ,[dbo].[tbl_ProblemBillingAudit].[RefNum]
			   ,[dbo].[tbl_ProblemBillingAudit].[Notes]
			   ,[dbo].[tbl_ProblemBillingAudit].[SysReplication] FROM [dbo].[tbl_ProblemBillingAudit]
		LEFT OUTER JOIN [dbo].[tbl_ProblemBillingAudit_New] ON [dbo].[tbl_ProblemBillingAudit_New].[ActionCount] = [dbo].[tbl_ProblemBillingAudit].[ActionCount] 
		WHERE [dbo].[tbl_ProblemBillingAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ProblemBillingAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ProblemBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemBillingAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemBillingAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemBillingAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemBillingAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ProblemBillingAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ProblemBillingAudit]

		SET @PrintMsg = 'Rename name new table tbl_ProblemBillingAudit_New to tbl_ProblemBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemBillingAudit_New', 'tbl_ProblemBillingAudit'

		SET @PrintMsg = 'Rename PK_tbl_ProblemBillingAudit_New Constraints to PK_tbl_ProblemBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemBillingAudit.PK_tbl_ProblemBillingAudit_New', 'PK_tbl_ProblemBillingAudit', 'INDEX'

	END
END

-- Create new table tbl_Problems_New with correct structure
PRINT 'Create new table tbl_Problems_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_Problems]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Description' AND TABLE_NAME= 'tbl_Problems' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_Problems_New] (
		[ProblemID] [int] NOT NULL,
		[ProblemPID] [int] NULL,
		[SiteID] [int] NULL,
		[HDUserID] [int] NULL,
		[DateEntered] [datetime] NULL,
		[LastUpdated] [datetime] NULL,
		[Closed] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[ResUserID] [int] NULL,
		[ClosureTypeID] [int] NULL,
		[DateStarted] [datetime] NULL,
		[ElapsedTime] [int] NULL,
		[ProblemTypeID] [int] NULL,
		[ReceivedByID] [int] NULL,
		[ProblemStatusID] [int] NULL,
		[Subject] [nvarchar](500) NULL,
		[Description] [nvarchar](max) NULL,
		[SolutionTypeID] [int] NULL,
		[Solution] [nvarchar](max) NULL,
		[HotNewsID] [int] NULL,
		[PriorityID] [int] NULL,
		[UrgencyID] [int] NULL,
		[RiskID] [int] NULL,
		[ServiceAreaID] [int] NULL,
		[Key1] [int] NULL,
		[Key2] [int] NULL,
		[Key3] [int] NULL,
		[ProductTypeID] [int] NULL,
		[ProductID] [int] NULL,
		[ImpactID] [int] NULL,
		[SymptomCodeID] [int] NULL,
		[CauseCodeID] [int] NULL,
		[DueDate] [datetime] NULL,
		[QueueID] [int] NULL,
		[GroupID] [int] NULL,
		[UserID] [int] NULL,
		[EstSolDate] [datetime] NULL,
		[Notification] [int] NULL,
		[EmailNotification] [bit] NULL,
		[ClosedOnCall] [bit] NULL,
		[CompanyName] [nvarchar](250) NULL,
		[CompanyID] [int] NULL,
		[ContactID] [int] NULL,
		[CompanyIDGUID] [varchar](100) NULL,
		[ContactIDGUID] [varchar](100) NULL,
		[FirstName] [nvarchar](100) NULL,
		[LastName] [nvarchar](100) NULL,
		[Email] [nvarchar](100) NULL,
		[Username] [nvarchar](200) NULL,
		[Phone] [nvarchar](100) NULL,
		[Division] [nvarchar](200) NULL,
		[Department] [nvarchar](200) NULL,
		[Location] [nvarchar](200) NULL,
		[Computer] [nvarchar](200) NULL,
		[ReqCompanyName] [nvarchar](250) NULL,
		[ReqCompanyID] [int] NULL,
		[ReqContactID] [int] NULL,
		[ReqCompanyIDGUID] [varchar](100) NULL,
		[ReqContactIDGUID] [varchar](100) NULL,
		[ReqFirstName] [nvarchar](100) NULL,
		[ReqLastName] [nvarchar](100) NULL,
		[ReqEmail] [nvarchar](100) NULL,
		[ReqUsername] [nvarchar](200) NULL,
		[ReqPhone] [nvarchar](100) NULL,
		[ReqDivision] [nvarchar](200) NULL,
		[ReqDepartment] [nvarchar](200) NULL,
		[ReqLocation] [nvarchar](200) NULL,
		[ReqComputer] [nvarchar](200) NULL,
		[BusinessImpactAnalysis] [nvarchar](max) NULL,
		[BusinessProductivityLoss] [nvarchar](250) NULL,
		[TechnicalResources] [nvarchar](max) NULL,
		[RootCauseKnownError] [bit] NULL,
		[RootCauseDateDetermined] [datetime] NULL,
		[RootCauseDeterminedByID] [int] NULL,
		[RootCauseTimeSpent] [int] NULL,
		[RootCauseCodeID] [int] NULL,
		[RootCauseDetails] [nvarchar](max) NULL,
		[WorkaroundDateCreated] [datetime] NULL,
		[WorkaroundCreatedByID] [int] NULL,
		[WorkaroundTimeSpent] [int] NULL,
		[WorkaroundCategoryID] [int] NULL,
		[WorkaroundTitle] [nvarchar](250) NULL,
		[WorkaroundDetails] [nvarchar](max) NULL,
		[DueDateNotification] [bit] NULL,
		[EstSolDateNotification] [bit] NULL,
		[OpenNotificationOnLog] [bit] NULL,
		[CloseNotificationOnLog] [bit] NULL,
		[SysReplication] [int] NULL,
		[ProblemLocked] [int] NULL,
		[ArchiveID] [int] NULL,
		[ArchiveDate] [datetime] NULL,
		[JobTitle] [nvarchar](200) NULL,
		[ReqJobTitle] [nvarchar](200) NULL,
	 CONSTRAINT [PK_tbl_Problems_New] PRIMARY KEY CLUSTERED 
	(
		[ProblemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_Problems to tbl_Problems_New
PRINT 'Copy rows from tbl_Problems to tbl_Problems_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_Problems_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_Problems_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_Problems_New]  WITH (TABLOCK) 
			   ([ProblemID]
			   ,[ProblemPID]
			   ,[SiteID]
			   ,[HDUserID]
			   ,[DateEntered]
			   ,[LastUpdated]
			   ,[Closed]
			   ,[PerformedOn]
			   ,[ResUserID]
			   ,[ClosureTypeID]
			   ,[DateStarted]
			   ,[ElapsedTime]
			   ,[ProblemTypeID]
			   ,[ReceivedByID]
			   ,[ProblemStatusID]
			   ,[Subject]
			   ,[Description]
			   ,[SolutionTypeID]
			   ,[Solution]
			   ,[HotNewsID]
			   ,[PriorityID]
			   ,[UrgencyID]
			   ,[RiskID]
			   ,[ServiceAreaID]
			   ,[Key1]
			   ,[Key2]
			   ,[Key3]
			   ,[ProductTypeID]
			   ,[ProductID]
			   ,[ImpactID]
			   ,[SymptomCodeID]
			   ,[CauseCodeID]
			   ,[DueDate]
			   ,[QueueID]
			   ,[GroupID]
			   ,[UserID]
			   ,[EstSolDate]
			   ,[Notification]
			   ,[EmailNotification]
			   ,[ClosedOnCall]
			   ,[CompanyName]
			   ,[CompanyID]
			   ,[ContactID]
			   ,[CompanyIDGUID]
			   ,[ContactIDGUID]
			   ,[FirstName]
			   ,[LastName]
			   ,[Email]
			   ,[Username]
			   ,[Phone]
			   ,[Division]
			   ,[Department]
			   ,[Location]
			   ,[Computer]
			   ,[ReqCompanyName]
			   ,[ReqCompanyID]
			   ,[ReqContactID]
			   ,[ReqCompanyIDGUID]
			   ,[ReqContactIDGUID]
			   ,[ReqFirstName]
			   ,[ReqLastName]
			   ,[ReqEmail]
			   ,[ReqUsername]
			   ,[ReqPhone]
			   ,[ReqDivision]
			   ,[ReqDepartment]
			   ,[ReqLocation]
			   ,[ReqComputer]
			   ,[BusinessImpactAnalysis]
			   ,[BusinessProductivityLoss]
			   ,[TechnicalResources]
			   ,[RootCauseKnownError]
			   ,[RootCauseDateDetermined]
			   ,[RootCauseDeterminedByID]
			   ,[RootCauseTimeSpent]
			   ,[RootCauseCodeID]
			   ,[RootCauseDetails]
			   ,[WorkaroundDateCreated]
			   ,[WorkaroundCreatedByID]
			   ,[WorkaroundTimeSpent]
			   ,[WorkaroundCategoryID]
			   ,[WorkaroundTitle]
			   ,[WorkaroundDetails]
			   ,[DueDateNotification]
			   ,[EstSolDateNotification]
			   ,[OpenNotificationOnLog]
			   ,[CloseNotificationOnLog]
			   ,[SysReplication]
			   ,[ProblemLocked]
			   ,[ArchiveID]
			   ,[ArchiveDate]
			   ,[JobTitle]
			   ,[ReqJobTitle])
		SELECT TOP (@BatchVolume)
			    [dbo].[tbl_Problems].[ProblemID]
			   ,[dbo].[tbl_Problems].[ProblemPID]
			   ,[dbo].[tbl_Problems].[SiteID]
			   ,[dbo].[tbl_Problems].[HDUserID]
			   ,[dbo].[tbl_Problems].[DateEntered]
			   ,[dbo].[tbl_Problems].[LastUpdated]
			   ,[dbo].[tbl_Problems].[Closed]
			   ,[dbo].[tbl_Problems].[PerformedOn]
			   ,[dbo].[tbl_Problems].[ResUserID]
			   ,[dbo].[tbl_Problems].[ClosureTypeID]
			   ,[dbo].[tbl_Problems].[DateStarted]
			   ,[dbo].[tbl_Problems].[ElapsedTime]
			   ,[dbo].[tbl_Problems].[ProblemTypeID]
			   ,[dbo].[tbl_Problems].[ReceivedByID]
			   ,[dbo].[tbl_Problems].[ProblemStatusID]
			   ,[dbo].[tbl_Problems].[Subject]
			   ,[dbo].[tbl_Problems].[Description]
			   ,[dbo].[tbl_Problems].[SolutionTypeID]
			   ,[dbo].[tbl_Problems].[Solution]
			   ,[dbo].[tbl_Problems].[HotNewsID]
			   ,[dbo].[tbl_Problems].[PriorityID]
			   ,[dbo].[tbl_Problems].[UrgencyID]
			   ,[dbo].[tbl_Problems].[RiskID]
			   ,[dbo].[tbl_Problems].[ServiceAreaID]
			   ,[dbo].[tbl_Problems].[Key1]
			   ,[dbo].[tbl_Problems].[Key2]
			   ,[dbo].[tbl_Problems].[Key3]
			   ,[dbo].[tbl_Problems].[ProductTypeID]
			   ,[dbo].[tbl_Problems].[ProductID]
			   ,[dbo].[tbl_Problems].[ImpactID]
			   ,[dbo].[tbl_Problems].[SymptomCodeID]
			   ,[dbo].[tbl_Problems].[CauseCodeID]
			   ,[dbo].[tbl_Problems].[DueDate]
			   ,[dbo].[tbl_Problems].[QueueID]
			   ,[dbo].[tbl_Problems].[GroupID]
			   ,[dbo].[tbl_Problems].[UserID]
			   ,[dbo].[tbl_Problems].[EstSolDate]
			   ,[dbo].[tbl_Problems].[Notification]
			   ,[dbo].[tbl_Problems].[EmailNotification]
			   ,[dbo].[tbl_Problems].[ClosedOnCall]
			   ,[dbo].[tbl_Problems].[CompanyName]
			   ,[dbo].[tbl_Problems].[CompanyID]
			   ,[dbo].[tbl_Problems].[ContactID]
			   ,[dbo].[tbl_Problems].[CompanyIDGUID]
			   ,[dbo].[tbl_Problems].[ContactIDGUID]
			   ,[dbo].[tbl_Problems].[FirstName]
			   ,[dbo].[tbl_Problems].[LastName]
			   ,[dbo].[tbl_Problems].[Email]
			   ,[dbo].[tbl_Problems].[Username]
			   ,[dbo].[tbl_Problems].[Phone]
			   ,[dbo].[tbl_Problems].[Division]
			   ,[dbo].[tbl_Problems].[Department]
			   ,[dbo].[tbl_Problems].[Location]
			   ,[dbo].[tbl_Problems].[Computer]
			   ,[dbo].[tbl_Problems].[ReqCompanyName]
			   ,[dbo].[tbl_Problems].[ReqCompanyID]
			   ,[dbo].[tbl_Problems].[ReqContactID]
			   ,[dbo].[tbl_Problems].[ReqCompanyIDGUID]
			   ,[dbo].[tbl_Problems].[ReqContactIDGUID]
			   ,[dbo].[tbl_Problems].[ReqFirstName]
			   ,[dbo].[tbl_Problems].[ReqLastName]
			   ,[dbo].[tbl_Problems].[ReqEmail]
			   ,[dbo].[tbl_Problems].[ReqUsername]
			   ,[dbo].[tbl_Problems].[ReqPhone]
			   ,[dbo].[tbl_Problems].[ReqDivision]
			   ,[dbo].[tbl_Problems].[ReqDepartment]
			   ,[dbo].[tbl_Problems].[ReqLocation]
			   ,[dbo].[tbl_Problems].[ReqComputer]
			   ,[dbo].[tbl_Problems].[BusinessImpactAnalysis]
			   ,[dbo].[tbl_Problems].[BusinessProductivityLoss]
			   ,[dbo].[tbl_Problems].[TechnicalResources]
			   ,[dbo].[tbl_Problems].[RootCauseKnownError]
			   ,[dbo].[tbl_Problems].[RootCauseDateDetermined]
			   ,[dbo].[tbl_Problems].[RootCauseDeterminedByID]
			   ,[dbo].[tbl_Problems].[RootCauseTimeSpent]
			   ,[dbo].[tbl_Problems].[RootCauseCodeID]
			   ,[dbo].[tbl_Problems].[RootCauseDetails]
			   ,[dbo].[tbl_Problems].[WorkaroundDateCreated]
			   ,[dbo].[tbl_Problems].[WorkaroundCreatedByID]
			   ,[dbo].[tbl_Problems].[WorkaroundTimeSpent]
			   ,[dbo].[tbl_Problems].[WorkaroundCategoryID]
			   ,[dbo].[tbl_Problems].[WorkaroundTitle]
			   ,[dbo].[tbl_Problems].[WorkaroundDetails]
			   ,[dbo].[tbl_Problems].[DueDateNotification]
			   ,[dbo].[tbl_Problems].[EstSolDateNotification]
			   ,[dbo].[tbl_Problems].[OpenNotificationOnLog]
			   ,[dbo].[tbl_Problems].[CloseNotificationOnLog]
			   ,[dbo].[tbl_Problems].[SysReplication]
			   ,[dbo].[tbl_Problems].[ProblemLocked]
			   ,[dbo].[tbl_Problems].[ArchiveID]
			   ,[dbo].[tbl_Problems].[ArchiveDate]
			   ,[dbo].[tbl_Problems].[JobTitle]
			   ,[dbo].[tbl_Problems].[ReqJobTitle] FROM [dbo].[tbl_Problems]
		LEFT OUTER JOIN [dbo].[tbl_Problems_New] ON [dbo].[tbl_Problems_New].[ProblemID] = [dbo].[tbl_Problems].[ProblemID] 
		WHERE [dbo].[tbl_Problems_New].[ProblemID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_Problems_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_Problems_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ProblemID) FROM [dbo].[tbl_Problems]
	SELECT @NewCount = COUNT(ProblemID) FROM [dbo].[tbl_Problems_New]

	SET @PrintMsg = 'Count [dbo].[tbl_Problems]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_Problems_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_Problems]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_Problems]

		SET @PrintMsg = 'Rename name new table tbl_Problems_New to tbl_Problems'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Problems_New', 'tbl_Problems'

		SET @PrintMsg = 'Rename PK_tbl_Problems_New Constraints to PK_tbl_Problems'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Problems.PK_tbl_Problems_New', 'PK_tbl_Problems', 'INDEX'

	END
END

-- Create new table tbl_ProblemAudit_New with correct structure
PRINT 'Create new table tbl_ProblemAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ProblemAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ProblemAudit_New] (
		[ActionCount] [int] NOT NULL,
		[ProblemID] [int] NULL,
		[LinkID] [int] NULL,
		[SiteID] [int] NULL,
		[ActionID] [int] NULL,
		[ActionDate] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[TimeWorked] [int] NULL,
		[UserID] [int] NULL,
		[Description] [nvarchar](max) NULL,
		[Notes] [nvarchar](max) NULL,
		[Headers] [nvarchar](max) NULL,
		[MailFrom] [nvarchar](max) NULL,
		[MailTo] [nvarchar](max) NULL,
		[MailCc] [nvarchar](max) NULL,
		[MailBcc] [nvarchar](max) NULL,
		[Subject] [nvarchar](max) NULL,
		[ResUserID] [int] NULL,
		[SendMail] [bit] NULL,
		[IsUnRead] [bit] NULL,
		[Flag] [int] NULL,
		[SysReplication] [int] NULL,
		[GeoLocation] [nvarchar](1000) NULL,
		[Timestamp] [timestamp] NOT NULL,
	 CONSTRAINT [PK_tbl_ProblemAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ProblemAudit to tbl_ProblemAudit_New
PRINT 'Copy rows from tbl_ProblemAudit to tbl_ProblemAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ProblemAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ProblemAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ProblemAudit_New]  WITH (TABLOCK) 
			([ActionCount]
           ,[ProblemID]
           ,[LinkID]
           ,[SiteID]
           ,[ActionID]
           ,[ActionDate]
           ,[PerformedOn]
           ,[TimeWorked]
           ,[UserID]
           ,[Description]
           ,[Notes]
           ,[Headers]
           ,[MailFrom]
           ,[MailTo]
           ,[MailCc]
           ,[MailBcc]
           ,[Subject]
           ,[ResUserID]
           ,[SendMail]
           ,[IsUnRead]
           ,[Flag]
           ,[SysReplication]
           ,[GeoLocation])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ProblemAudit].[ActionCount]
           ,[dbo].[tbl_ProblemAudit].[ProblemID]
           ,[dbo].[tbl_ProblemAudit].[LinkID]
           ,[dbo].[tbl_ProblemAudit].[SiteID]
           ,[dbo].[tbl_ProblemAudit].[ActionID]
           ,[dbo].[tbl_ProblemAudit].[ActionDate]
           ,[dbo].[tbl_ProblemAudit].[PerformedOn]
           ,[dbo].[tbl_ProblemAudit].[TimeWorked]
           ,[dbo].[tbl_ProblemAudit].[UserID]
           ,[dbo].[tbl_ProblemAudit].[Description]
           ,[dbo].[tbl_ProblemAudit].[Notes]
           ,[dbo].[tbl_ProblemAudit].[Headers]
           ,[dbo].[tbl_ProblemAudit].[MailFrom]
           ,[dbo].[tbl_ProblemAudit].[MailTo]
           ,[dbo].[tbl_ProblemAudit].[MailCc]
           ,[dbo].[tbl_ProblemAudit].[MailBcc]
           ,[dbo].[tbl_ProblemAudit].[Subject]
           ,[dbo].[tbl_ProblemAudit].[ResUserID]
           ,[dbo].[tbl_ProblemAudit].[SendMail]
           ,[dbo].[tbl_ProblemAudit].[IsUnRead]
           ,[dbo].[tbl_ProblemAudit].[Flag]
           ,[dbo].[tbl_ProblemAudit].[SysReplication]
           ,[dbo].[tbl_ProblemAudit].[GeoLocation] FROM [dbo].[tbl_ProblemAudit]
		LEFT OUTER JOIN [dbo].[tbl_ProblemAudit_New] ON [dbo].[tbl_ProblemAudit_New].[ActionCount] = [dbo].[tbl_ProblemAudit].[ActionCount] 
		WHERE [dbo].[tbl_ProblemAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ProblemAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ProblemAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ProblemAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ProblemAudit]

		SET @PrintMsg = 'Rename name new table tbl_ProblemAudit_New to tbl_ProblemAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAudit_New', 'tbl_ProblemAudit'

		SET @PrintMsg = 'Rename PK_tbl_ProblemAudit_New Constraints to PK_tbl_ProblemAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAudit.PK_tbl_ProblemAudit_New', 'PK_tbl_ProblemAudit', 'INDEX'

	END
END


-- Create new table tbl_ProblemAuditAttach_New with correct structure
PRINT 'Create new table tbl_ProblemAuditAttach_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemAuditAttach]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ProblemAuditAttach' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ProblemAuditAttach_New] (
		[ProblemID] [int] NULL,
		[ActionCount] [int] NOT NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ProblemAuditAttach_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC,
		[SeqNum] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ProblemAuditAttach to tbl_ProblemAuditAttach_New
PRINT 'Copy rows from tbl_ProblemAuditAttach to tbl_ProblemAuditAttach_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ProblemAuditAttach_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ProblemAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ProblemAuditAttach_New]  WITH (TABLOCK) 
			([ProblemID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ProblemAuditAttach].[ProblemID]
           ,[dbo].[tbl_ProblemAuditAttach].[ActionCount]
           ,[dbo].[tbl_ProblemAuditAttach].[SeqNum]
           ,[dbo].[tbl_ProblemAuditAttach].[Filename]
           ,[dbo].[tbl_ProblemAuditAttach].[FileSize]
           ,[dbo].[tbl_ProblemAuditAttach].[FileObject]
           ,[dbo].[tbl_ProblemAuditAttach].[UpdateGUID]
           ,[dbo].[tbl_ProblemAuditAttach].[SiteID]
           ,[dbo].[tbl_ProblemAuditAttach].[SysReplication] FROM [dbo].[tbl_ProblemAuditAttach]
		LEFT OUTER JOIN [dbo].[tbl_ProblemAuditAttach_New] ON [dbo].[tbl_ProblemAuditAttach_New].[ActionCount] = [dbo].[tbl_ProblemAuditAttach].[ActionCount] AND [dbo].[tbl_ProblemAuditAttach_New].[SeqNum] = [dbo].[tbl_ProblemAuditAttach].[SeqNum] 
		WHERE [dbo].[tbl_ProblemAuditAttach_New].[ActionCount] IS NULL AND [dbo].[tbl_ProblemAuditAttach_New].[SeqNum] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ProblemAuditAttach_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ProblemAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemAuditAttach]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ProblemAuditAttach_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAuditAttach]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAuditAttach_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ProblemAuditAttach]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ProblemAuditAttach]

		SET @PrintMsg = 'Rename name new table tbl_ProblemAuditAttach_New to tbl_ProblemAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAuditAttach_New', 'tbl_ProblemAuditAttach'

		SET @PrintMsg = 'Rename PK_tbl_ProblemAuditAttach_New Constraints to PK_tbl_ProblemAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAuditAttach.PK_tbl_ProblemAuditAttach_New', 'PK_tbl_ProblemAuditAttach', 'INDEX'

	END
END

-- Create new table tbl_ProblemAuditAttachTemp_New with correct structure
PRINT 'Create new table tbl_ProblemAuditAttachTemp_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ProblemAuditAttachTemp]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ProblemAuditAttachTemp' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ProblemAuditAttachTemp_New] (
		[TempGUID] [uniqueidentifier] NOT NULL,
		[ProblemID] [int] NULL,
		[ActionCount] [int] NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ProblemAuditAttachTemp_New] PRIMARY KEY CLUSTERED 
	(
		[TempGUID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ProblemAuditAttachTemp to tbl_ProblemAuditAttachTemp_New
PRINT 'Copy rows from tbl_ProblemAuditAttachTemp to tbl_ProblemAuditAttachTemp_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ProblemAuditAttachTemp_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime
	
	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ProblemAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ProblemAuditAttachTemp_New]  WITH (TABLOCK) 
			([TempGUID]
           ,[ProblemID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ProblemAuditAttachTemp].[TempGUID]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[ProblemID]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[ActionCount]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[SeqNum]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[Filename]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[FileSize]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[FileObject]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[UpdateGUID]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[SiteID]
           ,[dbo].[tbl_ProblemAuditAttachTemp].[SysReplication] FROM [dbo].[tbl_ProblemAuditAttachTemp] 
		LEFT OUTER JOIN [dbo].[tbl_ProblemAuditAttachTemp_New] ON [dbo].[tbl_ProblemAuditAttachTemp_New].[TempGUID] = [dbo].[tbl_ProblemAuditAttachTemp].[TempGUID] 
		WHERE [dbo].[tbl_ProblemAuditAttachTemp_New].[TempGUID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ProblemAuditAttachTemp_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ProblemAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT([TempGUID]) FROM [dbo].[tbl_ProblemAuditAttachTemp]
	SELECT @NewCount = COUNT([TempGUID]) FROM [dbo].[tbl_ProblemAuditAttachTemp_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAuditAttachTemp]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ProblemAuditAttachTemp_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ProblemAuditAttachTemp]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ProblemAuditAttachTemp]

		SET @PrintMsg = 'Rename name new table tbl_ProblemAuditAttachTemp_New to tbl_ProblemAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAuditAttachTemp_New', 'tbl_ProblemAuditAttachTemp'

		SET @PrintMsg = 'Rename PK_tbl_ProblemAuditAttachTemp_New Constraints to PK_tbl_ProblemAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ProblemAuditAttachTemp.PK_tbl_ProblemAuditAttachTemp_New', 'PK_tbl_ProblemAuditAttachTemp', 'INDEX'

	END
END

-- Set Recovery Mode back to "RECOVERY FULL"
PRINT 'Set Recovery Mode back to "RECOVERY FULL"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY FULL
GO

PRINT 'End Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO
