-- Alter ntext to nvarchar(max) 
-- tbl_ActionBilling
-- tbl_ActionBillingAudit
-- tbl_Actions
-- tbl_ActionAudit
-- tbl_ActionAuditAttach
-- tbl_ActionAuditAttachTemp

/*
So if we need use T-SQL to move data from one place to another one. It is recommended to use TABLOCK option on the destination table. With a few other constraints, the query can be executed with minimal logging.

The few constraints are:

The database must be in bulk logged recovery model.
The destination table must be empty or without clustered index.
There is no non-clustered index on the destination table.
*/

-- WITH (TABLOCK)
-- The above statement used in INSERT INTO statement will execute with minimal logging, hence improve execution time.
-- To enable "TABLOCK", the database must be in BULK_LOGGED or SIMPLE Recovery mode.

-- Set Recovery Mode to "SIMPLE"
PRINT 'Set Recovery Mode to "SIMPLE"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY SIMPLE
GO

Use [versaSRS]
GO

PRINT 'Start Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO

-- Drop FullText index on [dbo].[tbl_ActionAudit]
Print 'Drop FullText index on [dbo].[tbl_ActionAudit]'
GO
IF (EXISTS(SELECT * FROM sys.objects o inner join sys.fulltext_indexes fi on fi.object_id = o.object_id WHERE o.[object_id] = OBJECT_ID(N'[dbo].[tbl_ActionAudit]') AND [type]='U'))
	DROP FULLTEXT INDEX ON [dbo].[tbl_ActionAudit]
GO

-- Drop fulltext catalog [Task Search]
Print 'Drop fulltext catalog [Task Search]'
GO
IF (EXISTS(SELECT * FROM sys.fulltext_catalogs WHERE [name] = N'Task Search'))
	DROP FULLTEXT CATALOG [Task Search]
GO

-- Create new table tbl_ActionBilling_New with correct structure
PRINT 'Create new table tbl_ActionBilling_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ActionBilling]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ActionBilling' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ActionBilling_New] (
			[TaskID]              [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ActionBilling_New] PRIMARY KEY CLUSTERED 
	(
		[TaskID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ActionBilling to tbl_ActionBilling_New
PRINT 'Copy rows from tbl_ActionBilling to tbl_ActionBilling_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ActionBilling_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ActionBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ActionBilling_New] WITH (TABLOCK) 
			   ([TaskID]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ActionBilling].[TaskID]
			   ,[dbo].[tbl_ActionBilling].[SiteID]
			   ,[dbo].[tbl_ActionBilling].[NumTransactions]
			   ,[dbo].[tbl_ActionBilling].[CumulativeTime]
			   ,[dbo].[tbl_ActionBilling].[EstimatedTime]
			   ,[dbo].[tbl_ActionBilling].[Charge]
			   ,[dbo].[tbl_ActionBilling].[ChargeType]
			   ,[dbo].[tbl_ActionBilling].[ChargeCompany]
			   ,[dbo].[tbl_ActionBilling].[BilledTo]
			   ,[dbo].[tbl_ActionBilling].[SLA]
			   ,[dbo].[tbl_ActionBilling].[Quote]
			   ,[dbo].[tbl_ActionBilling].[RefNum]
			   ,[dbo].[tbl_ActionBilling].[Notes]
			   ,[dbo].[tbl_ActionBilling].[SysReplication] FROM [dbo].[tbl_ActionBilling]
		LEFT OUTER JOIN [dbo].[tbl_ActionBilling_New] ON [dbo].[tbl_ActionBilling_New].[TaskID] = [dbo].[tbl_ActionBilling].[TaskID] 
		WHERE [dbo].[tbl_ActionBilling_New].[TaskID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ActionBilling_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ActionBilling_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(TaskID) FROM [dbo].[tbl_ActionBilling]
	SELECT @NewCount = COUNT(TaskID) FROM [dbo].[tbl_ActionBilling_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ActionBilling]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ActionBilling_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ActionBilling]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ActionBilling]

		SET @PrintMsg = 'Rename name new table tbl_ActionBilling_New to tbl_ActionBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionBilling_New', 'tbl_ActionBilling'

		SET @PrintMsg = 'Rename PK_tbl_ActionBilling_New Constraints to PK_tbl_ActionBilling'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionBilling.PK_tbl_ActionBilling_New', 'PK_tbl_ActionBilling', 'INDEX'

	END
END

-- Create new table tbl_ActionBillingAudit_New with correct structure
PRINT 'Create new table tbl_ActionBillingAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ActionBillingAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ActionBillingAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ActionBillingAudit_New] (
			[ActionCount]         [int] NOT NULL,
			[SiteID]              [int] NULL,
			[NumTransactions]     [int] NULL,
			[BilledTime]          [int] NULL,
			[CumulativeTime]      [int] NULL,
			[EstimatedTime]       [int] NULL,
			[Charge]              [money] NULL,
			[ChargeType]          [int] NULL,
			[ChargeCompany]       [nvarchar](250) NULL,
			[BilledTo]            [int] NULL,
			[SLA]                 [nvarchar](255) NULL,
			[Quote]               [money] NULL,
			[RefNum]              [nvarchar](50) NULL,
			[Notes]               [nvarchar](max) NULL,
			[SysReplication]      [int] NULL,
	 CONSTRAINT [PK_tbl_ActionBillingAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO


-- Copy rows from tbl_ActionBillingAudit to tbl_ActionBillingAudit_New
PRINT 'Copy rows from tbl_ActionBillingAudit to tbl_ActionBillingAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ActionBillingAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ActionBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ActionBillingAudit_New]  WITH (TABLOCK) 
			   ([ActionCount]
			   ,[SiteID]
			   ,[NumTransactions]
			   ,[BilledTime]
			   ,[CumulativeTime]
			   ,[EstimatedTime]
			   ,[Charge]
			   ,[ChargeType]
			   ,[ChargeCompany]
			   ,[BilledTo]
			   ,[SLA]
			   ,[Quote]
			   ,[RefNum]
			   ,[Notes]
			   ,[SysReplication])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_ActionBillingAudit].[ActionCount]
			   ,[dbo].[tbl_ActionBillingAudit].[SiteID]
			   ,[dbo].[tbl_ActionBillingAudit].[NumTransactions]
			   ,[dbo].[tbl_ActionBillingAudit].[BilledTime]
			   ,[dbo].[tbl_ActionBillingAudit].[CumulativeTime]
			   ,[dbo].[tbl_ActionBillingAudit].[EstimatedTime]
			   ,[dbo].[tbl_ActionBillingAudit].[Charge]
			   ,[dbo].[tbl_ActionBillingAudit].[ChargeType]
			   ,[dbo].[tbl_ActionBillingAudit].[ChargeCompany]
			   ,[dbo].[tbl_ActionBillingAudit].[BilledTo]
			   ,[dbo].[tbl_ActionBillingAudit].[SLA]
			   ,[dbo].[tbl_ActionBillingAudit].[Quote]
			   ,[dbo].[tbl_ActionBillingAudit].[RefNum]
			   ,[dbo].[tbl_ActionBillingAudit].[Notes]
			   ,[dbo].[tbl_ActionBillingAudit].[SysReplication] FROM [dbo].[tbl_ActionBillingAudit]
		LEFT OUTER JOIN [dbo].[tbl_ActionBillingAudit_New] ON [dbo].[tbl_ActionBillingAudit_New].[ActionCount] = [dbo].[tbl_ActionBillingAudit].[ActionCount] 
		WHERE [dbo].[tbl_ActionBillingAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ActionBillingAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ActionBillingAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionBillingAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionBillingAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ActionBillingAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ActionBillingAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ActionBillingAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ActionBillingAudit]

		SET @PrintMsg = 'Rename name new table tbl_ActionBillingAudit_New to tbl_ActionBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionBillingAudit_New', 'tbl_ActionBillingAudit'

		SET @PrintMsg = 'Rename PK_tbl_ActionBillingAudit_New Constraints to PK_tbl_ActionBillingAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionBillingAudit.PK_tbl_ActionBillingAudit_New', 'PK_tbl_ActionBillingAudit', 'INDEX'

	END
END

-- Create new table tbl_Actions_New with correct structure
PRINT 'Create new table tbl_Actions_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_Actions]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'ActionDescription' AND TABLE_NAME= 'tbl_Actions' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_Actions_New] (
		[TaskID] [int] NOT NULL,
		[RecordID] [int] NULL,
		[SiteID] [int] NULL,
		[HDUserID] [int] NULL,
		[ActionTitle] [nvarchar](500) NULL,
		[ActionDescription] [nvarchar](max) NULL,
		[ActionTypeID] [int] NULL,
		[ActionCustom1ID] [int] NULL,
		[ActionCustom2ID] [int] NULL,
		[ActionCustom3ID] [int] NULL,
		[ActionCheck1] [bit] NULL,
		[Notes] [nvarchar](max) NULL,
		[ActionStatusID] [int] NULL,
		[PercentComplete] [int] NULL,
		[DateEntered] [datetime] NULL,
		[LastUpdated] [datetime] NULL,
		[DateStarted] [datetime] NULL,
		[DueDate] [datetime] NULL,
		[DateCompleted] [datetime] NULL,
		[RiskID] [int] NULL,
		[Resolution] [nvarchar](max) NULL,
		[AssignedToCompanyID] [int] NULL,
		[AssignedToContactID] [int] NULL,
		[AssignedToCompanyIDGUID] [varchar](100) NULL,
		[AssignedToContactIDGUID] [varchar](100) NULL,
		[AssignedToCompanyName] [nvarchar](250) NULL,
		[AssignedToFirstName] [nvarchar](100) NULL,
		[AssignedToLastName] [nvarchar](100) NULL,
		[AssignedToEmail] [nvarchar](100) NULL,
		[AssignedToUsername] [nvarchar](200) NULL,
		[AssignedToPhone] [nvarchar](100) NULL,
		[AssignedToDivision] [nvarchar](200) NULL,
		[AssignedToDepartment] [nvarchar](200) NULL,
		[AssignedToLocation] [nvarchar](200) NULL,
		[AssignedToComputer] [nvarchar](200) NULL,
		[SysReplication] [int] NULL,
		[ArchiveID] [int] NULL,
		[ArchiveDate] [datetime] NULL,
		[NotificationWhenLogged] [bit] NULL,
		[RecordTypeID] [int] NULL,
		[AssignedToJobTitle] [nvarchar](200) NULL,
		[DistributionGroupID] [int] NULL,
	 CONSTRAINT [PK_tbl_Actions_New] PRIMARY KEY CLUSTERED 
	(
		[TaskID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_Actions to tbl_Actions_New
PRINT 'Copy rows from tbl_Actions to tbl_Actions_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_Actions_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_Actions_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_Actions_New]  WITH (TABLOCK) 
			   ([TaskID]
			   ,[RecordID]
			   ,[SiteID]
			   ,[HDUserID]
			   ,[ActionTitle]
			   ,[ActionDescription]
			   ,[ActionTypeID]
			   ,[ActionCustom1ID]
			   ,[ActionCustom2ID]
			   ,[ActionCustom3ID]
			   ,[ActionCheck1]
			   ,[Notes]
			   ,[ActionStatusID]
			   ,[PercentComplete]
			   ,[DateEntered]
			   ,[LastUpdated]
			   ,[DateStarted]
			   ,[DueDate]
			   ,[DateCompleted]
			   ,[RiskID]
			   ,[Resolution]
			   ,[AssignedToCompanyID]
			   ,[AssignedToContactID]
			   ,[AssignedToCompanyIDGUID]
			   ,[AssignedToContactIDGUID]
			   ,[AssignedToCompanyName]
			   ,[AssignedToFirstName]
			   ,[AssignedToLastName]
			   ,[AssignedToEmail]
			   ,[AssignedToUsername]
			   ,[AssignedToPhone]
			   ,[AssignedToDivision]
			   ,[AssignedToDepartment]
			   ,[AssignedToLocation]
			   ,[AssignedToComputer]
			   ,[SysReplication]
			   ,[ArchiveID]
			   ,[ArchiveDate]
			   ,[NotificationWhenLogged]
			   ,[RecordTypeID]
			   ,[AssignedToJobTitle]
			   ,[DistributionGroupID])
		SELECT TOP (@BatchVolume)
			   [dbo].[tbl_Actions].[TaskID]
			   ,[dbo].[tbl_Actions].[RecordID]
			   ,[dbo].[tbl_Actions].[SiteID]
			   ,[dbo].[tbl_Actions].[HDUserID]
			   ,[dbo].[tbl_Actions].[ActionTitle]
			   ,[dbo].[tbl_Actions].[ActionDescription]
			   ,[dbo].[tbl_Actions].[ActionTypeID]
			   ,[dbo].[tbl_Actions].[ActionCustom1ID]
			   ,[dbo].[tbl_Actions].[ActionCustom2ID]
			   ,[dbo].[tbl_Actions].[ActionCustom3ID]
			   ,[dbo].[tbl_Actions].[ActionCheck1]
			   ,[dbo].[tbl_Actions].[Notes]
			   ,[dbo].[tbl_Actions].[ActionStatusID]
			   ,[dbo].[tbl_Actions].[PercentComplete]
			   ,[dbo].[tbl_Actions].[DateEntered]
			   ,[dbo].[tbl_Actions].[LastUpdated]
			   ,[dbo].[tbl_Actions].[DateStarted]
			   ,[dbo].[tbl_Actions].[DueDate]
			   ,[dbo].[tbl_Actions].[DateCompleted]
			   ,[dbo].[tbl_Actions].[RiskID]
			   ,[dbo].[tbl_Actions].[Resolution]
			   ,[dbo].[tbl_Actions].[AssignedToCompanyID]
			   ,[dbo].[tbl_Actions].[AssignedToContactID]
			   ,[dbo].[tbl_Actions].[AssignedToCompanyIDGUID]
			   ,[dbo].[tbl_Actions].[AssignedToContactIDGUID]
			   ,[dbo].[tbl_Actions].[AssignedToCompanyName]
			   ,[dbo].[tbl_Actions].[AssignedToFirstName]
			   ,[dbo].[tbl_Actions].[AssignedToLastName]
			   ,[dbo].[tbl_Actions].[AssignedToEmail]
			   ,[dbo].[tbl_Actions].[AssignedToUsername]
			   ,[dbo].[tbl_Actions].[AssignedToPhone]
			   ,[dbo].[tbl_Actions].[AssignedToDivision]
			   ,[dbo].[tbl_Actions].[AssignedToDepartment]
			   ,[dbo].[tbl_Actions].[AssignedToLocation]
			   ,[dbo].[tbl_Actions].[AssignedToComputer]
			   ,[dbo].[tbl_Actions].[SysReplication]
			   ,[dbo].[tbl_Actions].[ArchiveID]
			   ,[dbo].[tbl_Actions].[ArchiveDate]
			   ,[dbo].[tbl_Actions].[NotificationWhenLogged]
			   ,[dbo].[tbl_Actions].[RecordTypeID]
			   ,[dbo].[tbl_Actions].[AssignedToJobTitle]
			   ,[dbo].[tbl_Actions].[DistributionGroupID] FROM [dbo].[tbl_Actions]
		LEFT OUTER JOIN [dbo].[tbl_Actions_New] ON [dbo].[tbl_Actions_New].[TaskID] = [dbo].[tbl_Actions].[TaskID] 
		WHERE [dbo].[tbl_Actions_New].[TaskID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_Actions_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_Actions_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(TaskID) FROM [dbo].[tbl_Actions]
	SELECT @NewCount = COUNT(TaskID) FROM [dbo].[tbl_Actions_New]

	SET @PrintMsg = 'Count [dbo].[tbl_Actions]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_Actions_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_Actions]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_Actions]

		SET @PrintMsg = 'Rename name new table tbl_Actions_New to tbl_Actions'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Actions_New', 'tbl_Actions'

		SET @PrintMsg = 'Rename PK_tbl_Actions_New Constraints to PK_tbl_Actions'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_Actions.PK_tbl_Actions_New', 'PK_tbl_Actions', 'INDEX'

	END
END

-- Create new table tbl_ActionAudit_New with correct structure
PRINT 'Create new table tbl_ActionAudit_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ActionAudit]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'Notes' AND TABLE_NAME= 'tbl_ActionAudit' AND DATA_TYPE = 'ntext'))
	CREATE TABLE [dbo].[tbl_ActionAudit_New] (
		[ActionCount] [int] NOT NULL,
		[TaskID] [int] NULL,
		[RecordID] [int] NULL,
		[RecordTypeID] [int] NULL,
		[SiteID] [int] NULL,
		[ActionID] [int] NULL,
		[ActionDate] [datetime] NULL,
		[PerformedOn] [datetime] NULL,
		[TimeWorked] [int] NULL,
		[UserID] [int] NULL,
		[Description] [nvarchar](max) NULL,
		[Notes] [nvarchar](max) NULL,
		[Headers] [nvarchar](max) NULL,
		[MailFrom] [nvarchar](max) NULL,
		[MailTo] [nvarchar](max) NULL,
		[MailCc] [nvarchar](max) NULL,
		[MailBcc] [nvarchar](max) NULL,
		[Subject] [nvarchar](max) NULL,
		[ResUserID] [int] NULL,
		[SendMail] [bit] NULL,
		[IsUnRead] [bit] NULL,
		[Flag] [int] NULL,
		[SysReplication] [int] NULL,
		[GeoLocation] [nvarchar](1000) NULL,
		[Timestamp] [timestamp] NOT NULL,
	 CONSTRAINT [PK_tbl_ActionAudit_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ActionAudit to tbl_ActionAudit_New
PRINT 'Copy rows from tbl_ActionAudit to tbl_ActionAudit_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ActionAudit_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ActionAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ActionAudit_New]  WITH (TABLOCK) 
			([ActionCount]
           ,[TaskID]
           ,[RecordID]
           ,[RecordTypeID]
           ,[SiteID]
           ,[ActionID]
           ,[ActionDate]
           ,[PerformedOn]
           ,[TimeWorked]
           ,[UserID]
           ,[Description]
           ,[Notes]
           ,[Headers]
           ,[MailFrom]
           ,[MailTo]
           ,[MailCc]
           ,[MailBcc]
           ,[Subject]
           ,[ResUserID]
           ,[SendMail]
           ,[IsUnRead]
           ,[Flag]
           ,[SysReplication]
           ,[GeoLocation])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ActionAudit].[ActionCount]
           ,[dbo].[tbl_ActionAudit].[TaskID]
           ,[dbo].[tbl_ActionAudit].[RecordID]
           ,[dbo].[tbl_ActionAudit].[RecordTypeID]
           ,[dbo].[tbl_ActionAudit].[SiteID]
           ,[dbo].[tbl_ActionAudit].[ActionID]
           ,[dbo].[tbl_ActionAudit].[ActionDate]
           ,[dbo].[tbl_ActionAudit].[PerformedOn]
           ,[dbo].[tbl_ActionAudit].[TimeWorked]
           ,[dbo].[tbl_ActionAudit].[UserID]
           ,[dbo].[tbl_ActionAudit].[Description]
           ,[dbo].[tbl_ActionAudit].[Notes]
           ,[dbo].[tbl_ActionAudit].[Headers]
           ,[dbo].[tbl_ActionAudit].[MailFrom]
           ,[dbo].[tbl_ActionAudit].[MailTo]
           ,[dbo].[tbl_ActionAudit].[MailCc]
           ,[dbo].[tbl_ActionAudit].[MailBcc]
           ,[dbo].[tbl_ActionAudit].[Subject]
           ,[dbo].[tbl_ActionAudit].[ResUserID]
           ,[dbo].[tbl_ActionAudit].[SendMail]
           ,[dbo].[tbl_ActionAudit].[IsUnRead]
           ,[dbo].[tbl_ActionAudit].[Flag]
           ,[dbo].[tbl_ActionAudit].[SysReplication]
           ,[dbo].[tbl_ActionAudit].[GeoLocation] FROM [dbo].[tbl_ActionAudit]
		LEFT OUTER JOIN [dbo].[tbl_ActionAudit_New] ON [dbo].[tbl_ActionAudit_New].[ActionCount] = [dbo].[tbl_ActionAudit].[ActionCount] 
		WHERE [dbo].[tbl_ActionAudit_New].[ActionCount] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ActionAudit_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ActionAudit_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionAudit]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionAudit_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAudit]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAudit_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ActionAudit]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ActionAudit]

		SET @PrintMsg = 'Rename name new table tbl_ActionAudit_New to tbl_ActionAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAudit_New', 'tbl_ActionAudit'

		SET @PrintMsg = 'Rename PK_tbl_ActionAudit_New Constraints to PK_tbl_ActionAudit'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAudit.PK_tbl_ActionAudit_New', 'PK_tbl_ActionAudit', 'INDEX'

	END
END


-- Create new table tbl_ActionAuditAttach_New with correct structure
PRINT 'Create new table tbl_ActionAuditAttach_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ActionAuditAttach]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ActionAuditAttach' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ActionAuditAttach_New] (
		[TaskID] [int] NULL,
		[ActionCount] [int] NOT NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ActionAuditAttach_New] PRIMARY KEY CLUSTERED 
	(
		[ActionCount] ASC,
		[SeqNum] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ActionAuditAttach to tbl_ActionAuditAttach_New
PRINT 'Copy rows from tbl_ActionAuditAttach to tbl_ActionAuditAttach_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ActionAuditAttach_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime

	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ActionAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ActionAuditAttach_New]  WITH (TABLOCK) 
			([TaskID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ActionAuditAttach].[TaskID]
           ,[dbo].[tbl_ActionAuditAttach].[ActionCount]
           ,[dbo].[tbl_ActionAuditAttach].[SeqNum]
           ,[dbo].[tbl_ActionAuditAttach].[Filename]
           ,[dbo].[tbl_ActionAuditAttach].[FileSize]
           ,[dbo].[tbl_ActionAuditAttach].[FileObject]
           ,[dbo].[tbl_ActionAuditAttach].[UpdateGUID]
           ,[dbo].[tbl_ActionAuditAttach].[SiteID]
           ,[dbo].[tbl_ActionAuditAttach].[SysReplication] FROM [dbo].[tbl_ActionAuditAttach]
		LEFT OUTER JOIN [dbo].[tbl_ActionAuditAttach_New] ON [dbo].[tbl_ActionAuditAttach_New].[ActionCount] = [dbo].[tbl_ActionAuditAttach].[ActionCount] AND [dbo].[tbl_ActionAuditAttach_New].[SeqNum] = [dbo].[tbl_ActionAuditAttach].[SeqNum] 
		WHERE [dbo].[tbl_ActionAuditAttach_New].[ActionCount] IS NULL AND [dbo].[tbl_ActionAuditAttach_New].[SeqNum] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ActionAuditAttach_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ActionAuditAttach_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionAuditAttach]
	SELECT @NewCount = COUNT(ActionCount) FROM [dbo].[tbl_ActionAuditAttach_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAuditAttach]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAuditAttach_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ActionAuditAttach]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ActionAuditAttach]

		SET @PrintMsg = 'Rename name new table tbl_ActionAuditAttach_New to tbl_ActionAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAuditAttach_New', 'tbl_ActionAuditAttach'

		SET @PrintMsg = 'Rename PK_tbl_ActionAuditAttach_New Constraints to PK_tbl_ActionAuditAttach'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAuditAttach.PK_tbl_ActionAuditAttach_New', 'PK_tbl_ActionAuditAttach', 'INDEX'

	END
END

-- Create new table tbl_ActionAuditAttachTemp_New with correct structure
PRINT 'Create new table tbl_ActionAuditAttachTemp_New with correct structure'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[tbl_ActionAuditAttachTemp]') AND [type]='U')) AND (EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE COLUMN_NAME =N'FileObject' AND TABLE_NAME= 'tbl_ActionAuditAttachTemp' AND DATA_TYPE = 'image'))
	CREATE TABLE [dbo].[tbl_ActionAuditAttachTemp_New] (
		[TempGUID] [uniqueidentifier] NOT NULL,
		[TaskID] [int] NULL,
		[ActionCount] [int] NULL,
		[SeqNum] [int] NOT NULL,
		[Filename] [nvarchar](250) NULL,
		[FileSize] [int] NULL,
		[FileObject] [varbinary](max) NULL,
		[UpdateGUID] [nvarchar](100) NULL,
		[SiteID] [int] NULL,
		[SysReplication] [int] NULL,
	 CONSTRAINT [PK_tbl_ActionAuditAttachTemp_New] PRIMARY KEY CLUSTERED 
	(
		[TempGUID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

-- Copy rows from tbl_ActionAuditAttachTemp to tbl_ActionAuditAttachTemp_New
PRINT 'Copy rows from tbl_ActionAuditAttachTemp to tbl_ActionAuditAttachTemp_New'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE OBJECT_NAME([object_id]) = N'tbl_ActionAuditAttachTemp_New' AND [type]='U')) 
BEGIN
	DECLARE @OldCount int
	DECLARE @NewCount int
	DECLARE @RowsAffected int
	DECLARE @BatchVolume int
	DECLARE @BatchCounter int

	DECLARE @PrintMsg varchar(1000)
	DECLARE @StartTime datetime
	DECLARE @EndTime datetime
	
	SET @RowsAffected = 5000
	SET @BatchVolume = 5000
	SET @BatchCounter = 0

	SET @PrintMsg = 'Start Batch Insert for [dbo].[tbl_ActionAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108);
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	WHILE @RowsAffected = @BatchVolume
	BEGIN

		SET @BatchCounter = @BatchCounter + 1
		SET @StartTime = GETDATE()

		INSERT INTO [dbo].[tbl_ActionAuditAttachTemp_New]  WITH (TABLOCK) 
			([TempGUID]
           ,[TaskID]
           ,[ActionCount]
           ,[SeqNum]
           ,[Filename]
           ,[FileSize]
           ,[FileObject]
           ,[UpdateGUID]
           ,[SiteID]
           ,[SysReplication])
		SELECT TOP (@BatchVolume)
			[dbo].[tbl_ActionAuditAttachTemp].[TempGUID]
           ,[dbo].[tbl_ActionAuditAttachTemp].[TaskID]
           ,[dbo].[tbl_ActionAuditAttachTemp].[ActionCount]
           ,[dbo].[tbl_ActionAuditAttachTemp].[SeqNum]
           ,[dbo].[tbl_ActionAuditAttachTemp].[Filename]
           ,[dbo].[tbl_ActionAuditAttachTemp].[FileSize]
           ,[dbo].[tbl_ActionAuditAttachTemp].[FileObject]
           ,[dbo].[tbl_ActionAuditAttachTemp].[UpdateGUID]
           ,[dbo].[tbl_ActionAuditAttachTemp].[SiteID]
           ,[dbo].[tbl_ActionAuditAttachTemp].[SysReplication] FROM [dbo].[tbl_ActionAuditAttachTemp] 
		LEFT OUTER JOIN [dbo].[tbl_ActionAuditAttachTemp_New] ON [dbo].[tbl_ActionAuditAttachTemp_New].[TempGUID] = [dbo].[tbl_ActionAuditAttachTemp].[TempGUID]
		WHERE [dbo].[tbl_ActionAuditAttachTemp_New].[TempGUID] IS NULL 

		SET @RowsAffected = @@ROWCOUNT
		SET @EndTime = GETDATE()

		SET @PrintMsg = CAST(@BatchCounter As varchar) + '. Batch inserted ' + REPLACE(CONVERT(varchar, CAST(@RowsAffected AS money), 1), '.00', '') + ' rows into [dbo].[tbl_ActionAuditAttachTemp_New]      Duration: ' + dbo.udf_ConvertSeconds(DATEDIFF(SECOND, @StartTime, @EndTime))
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @PrintMsg = 'Total INSERTED: ' +  REPLACE(CONVERT(varchar, CAST((@BatchCounter * @RowsAffected) As money), 1), '.00', '')
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		CHECKPOINT 1; 

		RAISERROR('Wait for 5 Seconds...', 0, 1) WITH NOWAIT
		WAITFOR DELAY '00:00:05';

	END

	SET @PrintMsg = 'End Batch Insert for [dbo].[tbl_ActionAuditAttachTemp_New]: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SELECT @OldCount = COUNT([TempGUID]) FROM [dbo].[tbl_ActionAuditAttachTemp]
	SELECT @NewCount = COUNT([TempGUID]) FROM [dbo].[tbl_ActionAuditAttachTemp_New]

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAuditAttachTemp]: ' + CAST(@OldCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	SET @PrintMsg = 'Count [dbo].[tbl_ActionAuditAttachTemp_New]: ' + CAST(@NewCount As varchar)
	RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

	IF @OldCount = @NewCount
	BEGIN
		SET @PrintMsg = 'DROP table [dbo].[tbl_ActionAuditAttachTemp]'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		DROP TABLE [dbo].[tbl_ActionAuditAttachTemp]

		SET @PrintMsg = 'Rename name new table tbl_ActionAuditAttachTemp_New to tbl_ActionAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAuditAttachTemp_New', 'tbl_ActionAuditAttachTemp'

		SET @PrintMsg = 'Rename PK_tbl_ActionAuditAttachTemp_New Constraints to PK_tbl_ActionAuditAttachTemp'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT
		EXEC sp_rename 'tbl_ActionAuditAttachTemp.PK_tbl_ActionAuditAttachTemp_New', 'PK_tbl_ActionAuditAttachTemp', 'INDEX'

	END
END

-- Set Recovery Mode back to "RECOVERY FULL"
PRINT 'Set Recovery Mode back to "RECOVERY FULL"'
GO
USE master
ALTER DATABASE [versaSRS]
SET RECOVERY FULL
GO

PRINT 'End Time: ' + CONVERT(nvarchar(20), GETDATE(), 103) + ' ' + CONVERT(nvarchar(20), GETDATE(), 108)
GO
