/*
    Script Date: 	2017-11-20 02:40:46 AM
    Company: 	VersaDev Pty Ltd
    Author: 	CheanP
    Description: 	Script to create non-clustered indexes to improve performance on given database.

    Object: 	

                   Index: [versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID]
                   Index: [versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1]
                   Index: [versaIX_tbl_ProblemAudit_SendMail_INC1]
                   Index: [versaIX_tbl_ProblemAudit_UserIDActionID_INC1]
                   Index: [versaIX_tbl_ProblemAuditAttach_ProblemID]
                   Index: [versaIX_tbl_ProblemAuditAttach_UpdateGUID]
                   Index: [versaIX_tbl_Problems_ProblemPID]
                   Index: [versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1]
                   Index: [versaIX_tbl_Problems_ProblemStatusIDClosed_INC1]
                   Index: [versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID]
				   Index: [versaIX_tbl_Problems_ProblemLocked_INC1]


*/

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

USE [versaSRS]
GO

BEGIN TRAN

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAudit_ProblemID_IsUnReadActionID] ON [tbl_ProblemAudit] 
(
      [ProblemID], 
      [IsUnRead],[ActionID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1] INCLUDE ([ProblemID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAudit_IsUnReadActionID_INC1] ON [tbl_ProblemAudit] 
(
      [IsUnRead],[ActionID]
)  INCLUDE ([ProblemID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAudit_SendMail_INC1] INCLUDE ([ProblemID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_SendMail_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAudit_SendMail_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_SendMail_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAudit_SendMail_INC1] ON [tbl_ProblemAudit] 
(
      [SendMail]
)  INCLUDE ([ProblemID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAudit_UserIDActionID_INC1] INCLUDE ([ProblemID], [PerformedOn])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_UserIDActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAudit_UserIDActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAudit_UserIDActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAudit_UserIDActionID_INC1] ON [tbl_ProblemAudit] 
(
      [UserID],[ActionID]
)  INCLUDE ([ProblemID], [PerformedOn])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAuditAttach_ProblemID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAuditAttach_ProblemID') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAuditAttach_ProblemID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAuditAttach_ProblemID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAuditAttach_ProblemID] ON [tbl_ProblemAuditAttach] 
(
      [ProblemID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ProblemAuditAttach_UpdateGUID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAuditAttach_UpdateGUID') 
      PRINT 'Index with the name ''[versaIX_tbl_ProblemAuditAttach_UpdateGUID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ProblemAuditAttach_UpdateGUID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ProblemAuditAttach_UpdateGUID] ON [tbl_ProblemAuditAttach] 
(
      [UpdateGUID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Problems_ProblemPID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemPID') 
      PRINT 'Index with the name ''[versaIX_tbl_Problems_ProblemPID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemPID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Problems_ProblemPID] ON [tbl_Problems] 
(
      [ProblemPID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1] INCLUDE ([ProblemID], [ProblemPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [ProblemLocked])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Problems_ProblemStatusID_QueueID_INC1] ON [tbl_Problems] 
(
      [ProblemStatusID], 
      [QueueID]
)  INCLUDE ([ProblemID], [ProblemPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [ProblemLocked])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Problems_ProblemStatusIDClosed_INC1] INCLUDE ([UserID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemStatusIDClosed_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Problems_ProblemStatusIDClosed_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemStatusIDClosed_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Problems_ProblemStatusIDClosed_INC1] ON [tbl_Problems] 
(
      [ProblemStatusID],[Closed]
)  INCLUDE ([UserID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID') 
      PRINT 'Index with the name ''[versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Problems_QueueID_GroupID_UserIDProblemStatusID] ON [tbl_Problems] 
(
      [QueueID], 
      [GroupID], 
      [UserID],[ProblemStatusID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Problems_ProblemLocked_INC1] INCLUDE ([ProblemID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemLocked_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Problems_ProblemLocked_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Problems_ProblemLocked_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Problems_ProblemLocked_INC1] ON [tbl_Problems] 
(
      [ProblemLocked]
)  INCLUDE ([ProblemID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO


-- REBUILD INDEXES
PRINT 'Rebuild Indexes for tbl_ProblemAudit'
GO
ALTER INDEX ALL ON tbl_ProblemAudit REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'Rebuild Indexes for tbl_Problems'
GO
ALTER INDEX ALL ON tbl_Problems REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

IF @@TRANCOUNT>0
      COMMIT
GO
PRINT 'Index Creation Complete'
GO
SET NOEXEC OFF
GO
