/*
    Script Date: 	2017-11-20 02:40:46 AM
    Company: 	VersaDev Pty Ltd
    Author: 	CheanP
    Description: 	Script to create non-clustered indexes to improve performance on given database.

    Object: 	

                   Index: [versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID]
                   Index: [versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1]
                   Index: [versaIX_tbl_ChangeRequestAudit_SendMail_INC1]
                   Index: [versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1]
                   Index: [versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID]
                   Index: [versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID]
                   Index: [versaIX_tbl_ChangeRequests_ChangeRequestPID]
                   Index: [versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1]
                   Index: [versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1]
                   Index: [versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID]
				   Index: [versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1]


*/

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

USE [versaSRS]
GO

BEGIN TRAN

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAudit_ChangeRequestID_IsUnReadActionID] ON [tbl_ChangeRequestAudit] 
(
      [ChangeRequestID], 
      [IsUnRead],[ActionID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1] INCLUDE ([ChangeRequestID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAudit_IsUnReadActionID_INC1] ON [tbl_ChangeRequestAudit] 
(
      [IsUnRead],[ActionID]
)  INCLUDE ([ChangeRequestID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAudit_SendMail_INC1] INCLUDE ([ChangeRequestID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_SendMail_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAudit_SendMail_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_SendMail_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAudit_SendMail_INC1] ON [tbl_ChangeRequestAudit] 
(
      [SendMail]
)  INCLUDE ([ChangeRequestID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1] INCLUDE ([ChangeRequestID], [PerformedOn])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAudit_UserIDActionID_INC1] ON [tbl_ChangeRequestAudit] 
(
      [UserID],[ActionID]
)  INCLUDE ([ChangeRequestID], [PerformedOn])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAuditAttach_ChangeRequestID] ON [tbl_ChangeRequestAuditAttach] 
(
      [ChangeRequestID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequestAuditAttach_UpdateGUID] ON [tbl_ChangeRequestAuditAttach] 
(
      [UpdateGUID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequests_ChangeRequestPID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestPID') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequests_ChangeRequestPID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestPID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequests_ChangeRequestPID] ON [tbl_ChangeRequests] 
(
      [ChangeRequestPID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1] INCLUDE ([ChangeRequestID], [ChangeRequestPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [ChangeRequestLocked])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequests_ChangeRequestStatusID_QueueID_INC1] ON [tbl_ChangeRequests] 
(
      [ChangeRequestStatusID], 
      [QueueID]
)  INCLUDE ([ChangeRequestID], [ChangeRequestPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [ChangeRequestLocked])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1] INCLUDE ([UserID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequests_ChangeRequestStatusIDClosed_INC1] ON [tbl_ChangeRequests] 
(
      [ChangeRequestStatusID],[Closed]
)  INCLUDE ([UserID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequests_QueueID_GroupID_UserIDChangeRequestStatusID] ON [tbl_ChangeRequests] 
(
      [QueueID], 
      [GroupID], 
      [UserID],[ChangeRequestStatusID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1] INCLUDE ([ChangeRequestID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_ChangeRequests_ChangeRequestLocked_INC1] ON [tbl_ChangeRequests] 
(
      [ChangeRequestLocked]
)  INCLUDE ([ChangeRequestID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

-- REBUILD INDEXES
PRINT 'Rebuild Indexes for tbl_ChangeRequestAudit'
GO
ALTER INDEX ALL ON tbl_ChangeRequestAudit REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'Rebuild Indexes for tbl_ChangeRequests'
GO
ALTER INDEX ALL ON tbl_ChangeRequests REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

IF @@TRANCOUNT>0
      COMMIT
GO
PRINT 'Index Creation Complete'
GO
SET NOEXEC OFF
GO
