/*
    Script Date: 	2017-11-20 02:57:30 AM
    Company: 	VersaDev Pty Ltd
    Author: 	CheanP
    Description: 	Script to create non-clustered indexes to improve performance on given database.

    Object: 	

                   Index: [versaIX_tbl_Calls_ContactIDGUID_INC1]
                   Index: [versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber]


*/

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

USE [versaSRS]
GO

BEGIN TRAN

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_ContactIDGUID_INC1] INCLUDE ([CallID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_ContactIDGUID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_ContactIDGUID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_ContactIDGUID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_ContactIDGUID_INC1] ON [tbl_Calls] 
(
      [ContactIDGUID]
)  INCLUDE ([CallID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber') 
      PRINT 'Index with the name ''[versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_VCRMAddresses_ParentID_ParentTypeID_AddressNumber] ON [tbl_VCRMAddresses] 
(
      [ParentID], 
      [ParentTypeID], 
      [AddressNumber]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO


-- REBUILD INDEXES
PRINT 'Rebuild Indexes for tbl_Calls'
GO
ALTER INDEX ALL ON tbl_Calls REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'Rebuild Indexes for tbl_VCRMAddresses'
GO
ALTER INDEX ALL ON tbl_VCRMAddresses REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

IF @@TRANCOUNT>0
      COMMIT
GO
PRINT 'Index Creation Complete'
GO
SET NOEXEC OFF
GO
