/*
    Script Date: 	2017-11-20 02:40:46 AM
    Company: 	VersaDev Pty Ltd
    Author: 	CheanP
    Description: 	Script to create non-clustered indexes to improve performance on given database.

    Object: 	

                   Index: [versaIX_tbl_CallAudit_CallID_IsUnReadActionID]
                   Index: [versaIX_tbl_CallAudit_IsUnReadActionID_INC1]
                   Index: [versaIX_tbl_CallAudit_SendMail_INC1]
                   Index: [versaIX_tbl_CallAudit_UserIDActionID_INC1]
                   Index: [versaIX_tbl_CallAuditAttach_CallID]
                   Index: [versaIX_tbl_CallAuditAttach_UpdateGUID]
                   Index: [versaIX_tbl_Calls_CallPID]
                   Index: [versaIX_tbl_Calls_CallStatusID_QueueID_INC1]
                   Index: [versaIX_tbl_Calls_CallStatusIDClosed_INC1]
                   Index: [versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID]
                   Index: [versaIX_tbl_Calls_CallLocked_INC1]


*/

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

USE [versaSRS]
GO

BEGIN TRAN

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAudit_CallID_IsUnReadActionID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_CallID_IsUnReadActionID') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAudit_CallID_IsUnReadActionID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_CallID_IsUnReadActionID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAudit_CallID_IsUnReadActionID] ON [tbl_CallAudit] 
(
      [CallID], 
      [IsUnRead],[ActionID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAudit_IsUnReadActionID_INC1] INCLUDE ([CallID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_IsUnReadActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAudit_IsUnReadActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_IsUnReadActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAudit_IsUnReadActionID_INC1] ON [tbl_CallAudit] 
(
      [IsUnRead],[ActionID]
)  INCLUDE ([CallID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAudit_SendMail_INC1] INCLUDE ([CallID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_SendMail_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAudit_SendMail_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_SendMail_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAudit_SendMail_INC1] ON [tbl_CallAudit] 
(
      [SendMail]
)  INCLUDE ([CallID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAudit_UserIDActionID_INC1] INCLUDE ([CallID], [PerformedOn])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_UserIDActionID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAudit_UserIDActionID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAudit_UserIDActionID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAudit_UserIDActionID_INC1] ON [tbl_CallAudit] 
(
      [UserID],[ActionID]
)  INCLUDE ([CallID], [PerformedOn])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAuditAttach_CallID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAuditAttach_CallID') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAuditAttach_CallID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAuditAttach_CallID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAuditAttach_CallID] ON [tbl_CallAuditAttach] 
(
      [CallID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_CallAuditAttach_UpdateGUID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAuditAttach_UpdateGUID') 
      PRINT 'Index with the name ''[versaIX_tbl_CallAuditAttach_UpdateGUID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_CallAuditAttach_UpdateGUID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_CallAuditAttach_UpdateGUID] ON [tbl_CallAuditAttach] 
(
      [UpdateGUID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_CallPID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallPID') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_CallPID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallPID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_CallPID] ON [tbl_Calls] 
(
      [CallPID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_CallStatusID_QueueID_INC1] INCLUDE ([CallID], [CallPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [CallLocked])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallStatusID_QueueID_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_CallStatusID_QueueID_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallStatusID_QueueID_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_CallStatusID_QueueID_INC1] ON [tbl_Calls] 
(
      [CallStatusID], 
      [QueueID]
)  INCLUDE ([CallID], [CallPID], [HDUserID], [DateEntered], [Subject], [PriorityID], [Key1], [Key2], [Key3], [DueDate], [GroupID], [UserID], [CompanyName], [CompanyIDGUID], [FirstName], [LastName], [Username], [ReqCompanyName], [ReqFirstName], [ReqLastName], [ReqUsername], [CallLocked])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_CallStatusIDClosed_INC1] INCLUDE ([UserID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallStatusIDClosed_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_CallStatusIDClosed_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallStatusIDClosed_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_CallStatusIDClosed_INC1] ON [tbl_Calls] 
(
      [CallStatusID],[Closed]
)  INCLUDE ([UserID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID]'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_QueueID_GroupID_UserIDCallStatusID] ON [tbl_Calls] 
(
      [QueueID], 
      [GroupID], 
      [UserID],[CallStatusID]
) 
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'CREATE NONCLUSTERED INDEX: [versaIX_tbl_Calls_CallLocked_INC1] INCLUDE ([CallID])'
GO
IF EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallLocked_INC1') 
      PRINT 'Index with the name ''[versaIX_tbl_Calls_CallLocked_INC1]'' already exists. Skipped.'
GO
IF NOT EXISTS (SELECT name FROM sysindexes WHERE name = 'versaIX_tbl_Calls_CallLocked_INC1') 
      CREATE NONCLUSTERED INDEX [versaIX_tbl_Calls_CallLocked_INC1] ON [tbl_Calls] 
(
      [CallLocked]
)  INCLUDE ([CallID])
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

-- REBUILD INDEXES
PRINT 'Rebuild Indexes for tbl_CallAudit'
GO
ALTER INDEX ALL ON tbl_CallAudit REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

PRINT 'Rebuild Indexes for tbl_Calls'
GO
ALTER INDEX ALL ON tbl_Calls REBUILD WITH (FILLFACTOR = 90)
GO
-- TRANSACTION HANDLING
IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO

IF @@TRANCOUNT>0
      COMMIT
GO
PRINT 'Index Creation Complete'
GO
SET NOEXEC OFF
GO
