USE versaSRS;  
GO  
-- Find the average fragmentation percentage of all indexes  

DECLARE @IndexID int
DECLARE @IndexName nvarchar(500)
DECLARE @TableName nvarchar(500)
DECLARE @FragPercent decimal(10,2)

DECLARE @PrintMsg nvarchar(max)
DECLARE @Query nvarchar(max)

DECLARE INDEXCURSOR CURSOR
KEYSET
FOR

SELECT a.index_id, name, OBJECT_NAME(b.object_id) As tname, avg_fragmentation_in_percent  
FROM sys.dm_db_index_physical_stats (DB_ID(N'versaSRS'), 
      NULL, NULL, NULL, NULL) AS a  
    JOIN sys.indexes AS b 
      ON a.object_id = b.object_id AND a.index_id = b.index_id 
	  ORDER BY avg_fragmentation_in_percent DESC

	OPEN INDEXCURSOR
	FETCH NEXT From INDEXCURSOR INTO @IndexID, @IndexName, @TableName, @FragPercent

	WHILE @@FETCH_STATUS = 0
	BEGIN

		SET @PrintMsg = 'PRINT ' + CHAR(39) + 'REBUILD ALL INDEX FOR ' + @TableName + CHAR(39) + ';'
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		SET @Query = 'ALTER INDEX ALL ON ' + @TableName + CHAR(13) + 'REBUILD WITH (FILLFACTOR = 90, SORT_IN_TEMPDB = ON, STATISTICS_NORECOMPUTE = ON);' + CHAR(13)
		SET @PrintMsg = @Query
		RAISERROR(@PrintMsg, 0, 1) WITH NOWAIT

		FETCH NEXT From INDEXCURSOR INTO @IndexID, @IndexName, @TableName, @FragPercent
	END

CLOSE INDEXCURSOR
DEALLOCATE INDEXCURSOR


