/*
    Script Date: 	2017-11-20 02:40:46 AM
    Company: 	VersaDev Pty Ltd
    Author: 	CheanP
    Description: 	Script to create non-clustered indexes to improve performance on given database.

    Stored Procedures: 	

                   [sp_Call_Search_By_Page]
                   [sp_ChangeRequest_Search_By_Page]
                   [sp_Problem_Search_By_Page]


*/

SET NOEXEC OFF
SET ANSI_WARNINGS ON
SET XACT_ABORT ON
SET IMPLICIT_TRANSACTIONS OFF
SET ARITHABORT ON
SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
SET CONCAT_NULL_YIELDS_NULL ON
SET ANSI_NULLS ON
SET ANSI_PADDING ON
GO

USE [versaSRS]
GO

BEGIN TRAN

-- Drop Procedure [dbo].[sp_Call_Search_By_Page]
Print 'Drop Procedure [dbo].[sp_Call_Search_By_Page]'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[sp_Call_Search_By_Page]') AND [type]='P'))
DROP PROCEDURE [dbo].[sp_Call_Search_By_Page]
GO

IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO
CREATE PROCEDURE [dbo].[sp_Call_Search_By_Page]
@Filter varchar(5000),
@ReqStatusID int,
@SortBy int,
@SortOrder int,
@CurrentPage int,
@PageSize int,
@DateMode int,
@StartDate varchar(22),
@EndDate varchar(22),
@TotalRecords int output
AS

/*

	@ReqStatusID = 1	New
	@ReqStatusID = 2	Open
	@ReqStatusID = 3	Closed
	@ReqStatusID = 4	Pending
	@ReqStatusID = 5	Stalled
	@ReqStatusID = 6	Dead
	@ReqStatusID = 7	Re-Opened
	
	@ReqStatusID = 100	Current (New, Open, Pending, Re-Opened)
	@ReqStatusID = 101	Doesn't Matter (New, Open, Closed, Pending, Stalled, Dead, Re-Opened)

*/

-- Create A Temporary Table To Hold The Current Page Of Data --

DECLARE @str1 as nvarchar(max)
DECLARE @SortIndex As nvarchar(255)

SET @str1 = 'SELECT DISTINCT TOP 100 PERCENT (vew_CallAndAuditDetails.CallID), 
	vew_CallAndAuditDetails.DateEntered, 
	vew_CallAndAuditDetails.CallStatusID,
	vew_CallAndAuditDetails.HDUserID,
	vew_CallAndAuditDetails.FirstName As CFN, 
	vew_CallAndAuditDetails.LastName As CLN, 
	vew_CallAndAuditDetails.ReqFirstName As RFN, 
	vew_CallAndAuditDetails.ReqLastName As RLN, 	
	vew_CallAndAuditDetails.Subject,
	vew_CallAndAuditDetails.GroupID, 
	vew_CallAndAuditDetails.UserID, 
	vew_CallAndAuditDetails.PriorityID,
	tbl_QueueDueDates.DisplayLabel AS PriorityLabel,
	vew_CallAndAuditDetails.DueDate, 
	vew_CallAndAuditDetails.EstSolDate,
	vew_CallAndAuditDetails.CallLocked,
	tbl_CallStatus.CallStatusTitle, 
	tbl_Users.FirstName As LFN, tbl_Users.LastName As LLN, 
	tbl_Groups.GroupName,
	DUMYTABLE.FirstName AS OFN, DUMYTABLE.LastName AS OLN, 
	DUMYTABLE2.FirstName AS LOCKFN, DUMYTABLE2.LastName AS LOCKLN,
	(select count(CallID) from tbl_CallAuditAttach WITH (NOLOCK) Where CallID= vew_CallAndAuditDetails.CallID) As NumAtt
	FROM vew_CallAndAuditDetails
	LEFT OUTER JOIN tbl_QueueDueDates WITH (NOLOCK) ON vew_CallAndAuditDetails.PriorityID = tbl_QueueDueDates.PriorityID AND vew_CallAndAuditDetails.QueueID = tbl_QueueDueDates.QueueID
	LEFT OUTER JOIN tbl_Users DUMYTABLE WITH (NOLOCK) ON vew_CallAndAuditDetails.UserID = DUMYTABLE.UserID 
	LEFT OUTER JOIN tbl_Users DUMYTABLE2 WITH (NOLOCK) ON vew_CallAndAuditDetails.CallLocked = DUMYTABLE2.UserID 
	Left Outer Join tbl_CallStatus WITH (NOLOCK) On vew_CallAndAuditDetails.CallStatusID = tbl_CallStatus.CallStatusID 
	Left Outer Join tbl_Users WITH (NOLOCK) On vew_CallAndAuditDetails.HDUserID = tbl_Users.UserID
	Left Outer Join tbl_Groups WITH (NOLOCK) On vew_CallAndAuditDetails.GroupID = tbl_Groups.GroupID 
	WHERE (' + @Filter + ')'


	IF @ReqStatusID < 100
	BEGIN
		SET @str1 = @str1 + ' And vew_CallAndAuditDetails.CallStatusID = ' + CAST(@ReqStatusID AS varchar)
	END

	IF @ReqStatusID = 100
	BEGIN
		SET @str1 = @str1 + ' And (vew_CallAndAuditDetails.CallStatusID IN (1, 2, 7, 4))'
	END

	IF @ReqStatusID = 101
	BEGIN
		SET @str1 = @str1 + ' And (vew_CallAndAuditDetails.CallStatusID IN (1, 2, 3, 4, 5, 6, 7, 8))'
	END


	IF @DateMode = 1
	BEGIN
		SET @str1 = @str1 + ' AND (vew_CallAndAuditDetails.DateEntered BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 2
	BEGIN
		SET @str1 = @str1 + ' AND (vew_CallAndAuditDetails.DueDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 3
	BEGIN
		SET @str1 = @str1 + ' AND (vew_CallAndAuditDetails.EstSolDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 4
	BEGIN
		SET @str1 = @str1 + ' AND (vew_CallAndAuditDetails.Closed BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	SET @str1 = @str1 + ' ORDER BY '
	SET @SortIndex = 'RecordID'

	IF @SortBy = 0
	BEGIN
		SET @str1 = @str1 + 'CallID'
	END

	IF @SortBy = 1
	BEGIN
		SET @str1 = @str1 + 'CallID'
	END

	IF @SortBy = 2
	BEGIN
		SET @str1 = @str1 + 'tbl_CallStatus.CallStatusTitle'
		SET @SortIndex = 'RecordStatusTitle'
	END

	IF @SortBy = 3
	BEGIN
		SET @str1 = @str1 + 'vew_CallAndAuditDetails.PriorityID'
		SET @SortIndex = 'PriorityID'
	END

	IF @SortBy = 4
	BEGIN
		SET @str1 = @str1 + 'vew_CallAndAuditDetails.DueDate'
		SET @SortIndex = 'DueDate'
	END

	IF @SortBy = 5
	BEGIN
		SET @str1 = @str1 + 'vew_CallAndAuditDetails.FirstName'
		SET @SortIndex = 'CFN, CLN'
	END

	IF @SortBy = 6
	BEGIN
		SET @str1 = @str1 + 'vew_CallAndAuditDetails.Subject'
		SET @SortIndex = 'Subject'
	END

	IF @SortBy = 7
	BEGIN
		SET @str1 = @str1 + 'OFN'
		SET @SortIndex = 'OFN, OLN'
	END

	IF @SortBy = 8
	BEGIN
		SET @str1 = @str1 + 'tbl_Groups.GroupName'
		SET @SortIndex = 'GroupName'
	END

	IF @SortBy = 9
	BEGIN
		SET @str1 = @str1 + 'LFN'
		SET @SortIndex = 'LFN, LLN'
	END

	IF @SortBy = 10
	BEGIN
		SET @str1 = @str1 + 'vew_CallAndAuditDetails.DateEntered'
		SET @SortIndex = 'DateEntered'
	END

	IF @SortOrder = 0
	BEGIN
		SET @str1 = @str1 + ' DESC'
	END

	IF @SortOrder = 1
	BEGIN
		SET @str1 = @str1 + ' ASC'
	END

CREATE TABLE #TempTable
(
	ID int IDENTITY,
	[Timestamp] timestamp, 
	RecordID int,
	DateEntered datetime,
	RecordStatusID int,
	HDUserID int,
	CFN nvarchar(100),
	CLN nvarchar(100),
	RFN nvarchar(100),
	RLN nvarchar(100),
	Subject nvarchar(500),
	GroupID int,
	UserID int,
	PriorityID int,
	PriorityLabel nvarchar(255),
	DueDate datetime,
	EstSolDate datetime,
	RecordLocked int,
	RecordStatusTitle nvarchar(50),
	LFN nvarchar(30),
	LLN nvarchar(30),
	GroupName nvarchar(50),
	OFN nvarchar(30),
	OLN nvarchar(30),
	LOCKFN nvarchar(30),
	LOCKLN nvarchar(30),
	NumAtt int
)

-- Create Index for TempTable with Unique Index Name
DECLARE @strIndexQuery nvarchar(1000)
SET @strIndexQuery = 'CREATE INDEX IX_TempTable_' + REPLACE(CAST(NEWID() As varchar(50)), '-', '_') + ' ON tempdb..#TempTable (' + @SortIndex + ')'
EXEC(@strIndexQuery)

-- Fill The Temporary Table With Appropriate Call Data --
INSERT INTO #TempTable
(
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt
)


EXEC(@str1)


-- Create A Variable To Identify The First And Last Record That Should Be Selected --

DECLARE @FirstRec int, @LastRec int
SELECT @FirstRec = (@CurrentPage - 1) * @PageSize
SELECT @LastRec = (@CurrentPage * @PageSize + 1)

-- Select One Page Of Data Based On The Record Numbers Above --

SELECT
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt	
	FROM #TempTable
WHERE
	ID > @FirstRec
AND
	ID < @LastRec

-- Return The Total Number Of Records Available As An Output Parameter --

SELECT @TotalRecords = COUNT(*) FROM #TempTable
GO

-- Drop Procedure [dbo].[sp_ChangeRequest_Search_By_Page]
Print 'Drop Procedure [dbo].[sp_ChangeRequest_Search_By_Page]'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[sp_ChangeRequest_Search_By_Page]') AND [type]='P'))
DROP PROCEDURE [dbo].[sp_ChangeRequest_Search_By_Page]
GO

IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO
CREATE PROCEDURE [dbo].[sp_ChangeRequest_Search_By_Page]
@Filter varchar(5000),
@ReqStatusID int,
@SortBy int,
@SortOrder int,
@CurrentPage int,
@PageSize int,
@DateMode int,
@StartDate varchar(22),
@EndDate varchar(22),
@TotalRecords int output
AS

/*

	@ReqStatusID = 1	New
	@ReqStatusID = 2	Open
	@ReqStatusID = 3	Closed
	@ReqStatusID = 4	Pending
	@ReqStatusID = 5	Stalled
	@ReqStatusID = 6	Dead
	@ReqStatusID = 7	Re-Opened
	
	@ReqStatusID = 100	Current (New, Open, Pending, Re-Opened)
	@ReqStatusID = 101	Doesn't Matter (New, Open, Closed, Pending, Stalled, Dead, Re-Opened)

*/

-- Create A Temporary Table To Hold The Current Page Of Data --

DECLARE @str1 as nvarchar(max)
DECLARE @SortIndex As nvarchar(255)

SET @str1 = 'SELECT DISTINCT TOP 100 PERCENT (vew_ChangeRequestAndAuditDetails.ChangeRequestID), 
	vew_ChangeRequestAndAuditDetails.DateEntered, 
	vew_ChangeRequestAndAuditDetails.ChangeRequestStatusID,
	vew_ChangeRequestAndAuditDetails.HDUserID,
	vew_ChangeRequestAndAuditDetails.FirstName As CFN, 
	vew_ChangeRequestAndAuditDetails.LastName As CLN, 
	vew_ChangeRequestAndAuditDetails.ReqFirstName As RFN, 
	vew_ChangeRequestAndAuditDetails.ReqLastName As RLN, 	
	vew_ChangeRequestAndAuditDetails.Subject,
	vew_ChangeRequestAndAuditDetails.GroupID, 
	vew_ChangeRequestAndAuditDetails.UserID, 
	vew_ChangeRequestAndAuditDetails.PriorityID,
	tbl_QueueDueDates.DisplayLabel AS PriorityLabel,
	vew_ChangeRequestAndAuditDetails.DueDate, 
	vew_ChangeRequestAndAuditDetails.EstSolDate,
	vew_ChangeRequestAndAuditDetails.ChangeRequestLocked,
	tbl_ChangeRequestStatus.ChangeRequestStatusTitle, 
	tbl_Users.FirstName As LFN, tbl_Users.LastName As LLN, 
	tbl_Groups.GroupName,
	DUMYTABLE.FirstName AS OFN, DUMYTABLE.LastName AS OLN, 
	DUMYTABLE2.FirstName AS LOCKFN, DUMYTABLE2.LastName AS LOCKLN,
	(select count(ChangeRequestID) from tbl_ChangeRequestAuditAttach WITH (NOLOCK) Where ChangeRequestID= vew_ChangeRequestAndAuditDetails.ChangeRequestID) As NumAtt
	FROM vew_ChangeRequestAndAuditDetails
	LEFT OUTER JOIN tbl_QueueDueDates WITH (NOLOCK) ON vew_ChangeRequestAndAuditDetails.PriorityID = tbl_QueueDueDates.PriorityID AND vew_ChangeRequestAndAuditDetails.QueueID = tbl_QueueDueDates.QueueID
	LEFT OUTER JOIN tbl_Users DUMYTABLE WITH (NOLOCK) ON vew_ChangeRequestAndAuditDetails.UserID = DUMYTABLE.UserID 
	LEFT OUTER JOIN tbl_Users DUMYTABLE2 WITH (NOLOCK) ON vew_ChangeRequestAndAuditDetails.ChangeRequestLocked = DUMYTABLE2.UserID 
	Left Outer Join tbl_ChangeRequestStatus WITH (NOLOCK) On vew_ChangeRequestAndAuditDetails.ChangeRequestStatusID = tbl_ChangeRequestStatus.ChangeRequestStatusID 
	Left Outer Join tbl_Users WITH (NOLOCK) On vew_ChangeRequestAndAuditDetails.HDUserID = tbl_Users.UserID
	Left Outer Join tbl_Groups WITH (NOLOCK) On vew_ChangeRequestAndAuditDetails.GroupID = tbl_Groups.GroupID 
	WHERE (' + @Filter + ')'


	IF @ReqStatusID < 100
	BEGIN
		SET @str1 = @str1 + ' And vew_ChangeRequestAndAuditDetails.ChangeRequestStatusID = ' + CAST(@ReqStatusID AS varchar)
	END

	IF @ReqStatusID = 100
	BEGIN
		SET @str1 = @str1 + ' And (vew_ChangeRequestAndAuditDetails.ChangeRequestStatusID IN (1, 2, 7, 4))'
	END

	IF @ReqStatusID = 101
	BEGIN
		SET @str1 = @str1 + ' And (vew_ChangeRequestAndAuditDetails.ChangeRequestStatusID IN (1, 2, 3, 4, 5, 6, 7, 8))'
	END


	IF @DateMode = 1
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ChangeRequestAndAuditDetails.DateEntered BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 2
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ChangeRequestAndAuditDetails.DueDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 3
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ChangeRequestAndAuditDetails.EstSolDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 4
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ChangeRequestAndAuditDetails.Closed BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	SET @str1 = @str1 + ' ORDER BY '
	SET @SortIndex = 'RecordID'

	IF @SortBy = 0
	BEGIN
		SET @str1 = @str1 + 'ChangeRequestID'
	END

	IF @SortBy = 1
	BEGIN
		SET @str1 = @str1 + 'ChangeRequestID'
	END

	IF @SortBy = 2
	BEGIN
		SET @str1 = @str1 + 'tbl_ChangeRequestStatus.ChangeRequestStatusTitle'
		SET @SortIndex = 'RecordStatusTitle'
	END

	IF @SortBy = 3
	BEGIN
		SET @str1 = @str1 + 'vew_ChangeRequestAndAuditDetails.PriorityID'
		SET @SortIndex = 'PriorityID'
	END

	IF @SortBy = 4
	BEGIN
		SET @str1 = @str1 + 'vew_ChangeRequestAndAuditDetails.DueDate'
		SET @SortIndex = 'DueDate'
	END

	IF @SortBy = 5
	BEGIN
		SET @str1 = @str1 + 'vew_ChangeRequestAndAuditDetails.FirstName'
		SET @SortIndex = 'CFN, CLN'
	END

	IF @SortBy = 6
	BEGIN
		SET @str1 = @str1 + 'vew_ChangeRequestAndAuditDetails.Subject'
		SET @SortIndex = 'Subject'
	END

	IF @SortBy = 7
	BEGIN
		SET @str1 = @str1 + 'OFN'
		SET @SortIndex = 'OFN, OLN'
	END

	IF @SortBy = 8
	BEGIN
		SET @str1 = @str1 + 'tbl_Groups.GroupName'
		SET @SortIndex = 'GroupName'
	END

	IF @SortBy = 9
	BEGIN
		SET @str1 = @str1 + 'LFN'
		SET @SortIndex = 'LFN, LLN'
	END

	IF @SortBy = 10
	BEGIN
		SET @str1 = @str1 + 'vew_ChangeRequestAndAuditDetails.DateEntered'
		SET @SortIndex = 'DateEntered'
	END

	IF @SortOrder = 0
	BEGIN
		SET @str1 = @str1 + ' DESC'
	END

	IF @SortOrder = 1
	BEGIN
		SET @str1 = @str1 + ' ASC'
	END


CREATE TABLE #TempTable
(
	ID int IDENTITY,
	[Timestamp] timestamp, 
	RecordID int,
	DateEntered datetime,
	RecordStatusID int,
	HDUserID int,
	CFN nvarchar(100),
	CLN nvarchar(100),
	RFN nvarchar(100),
	RLN nvarchar(100),
	Subject nvarchar(500),
	GroupID int,
	UserID int,
	PriorityID int,
	PriorityLabel nvarchar(255),
	DueDate datetime,
	EstSolDate datetime,
	RecordLocked int,
	RecordStatusTitle nvarchar(50),
	LFN nvarchar(30),
	LLN nvarchar(30),
	GroupName nvarchar(50),
	OFN nvarchar(30),
	OLN nvarchar(30),
	LOCKFN nvarchar(30),
	LOCKLN nvarchar(30),
	NumAtt int
)

-- Create Index for TempTable with Unique Index Name
DECLARE @strIndexQuery nvarchar(1000)
SET @strIndexQuery = 'CREATE INDEX IX_TempTable_' + REPLACE(CAST(NEWID() As varchar(50)), '-', '_') + ' ON tempdb..#TempTable (' + @SortIndex + ')'
EXEC(@strIndexQuery)

-- Fill The Temporary Table With Appropriate ChangeRequest Data --
INSERT INTO #TempTable
(
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt
)


EXEC(@str1)


-- Create A Variable To Identify The First And Last Record That Should Be Selected --

DECLARE @FirstRec int, @LastRec int
SELECT @FirstRec = (@CurrentPage - 1) * @PageSize
SELECT @LastRec = (@CurrentPage * @PageSize + 1)

-- Select One Page Of Data Based On The Record Numbers Above --

SELECT
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt	
	FROM #TempTable
WHERE
	ID > @FirstRec
AND
	ID < @LastRec

-- Return The Total Number Of Records Available As An Output Parameter --

SELECT @TotalRecords = COUNT(*) FROM #TempTable
GO


-- Drop Procedure [dbo].[sp_Problem_Search_By_Page]
Print 'Drop Procedure [dbo].[sp_Problem_Search_By_Page]'
GO
IF (EXISTS(SELECT * FROM sys.objects WHERE [object_id] = OBJECT_ID(N'[dbo].[sp_Problem_Search_By_Page]') AND [type]='P'))
DROP PROCEDURE [dbo].sp_Problem_Search_By_Page
GO

IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO
CREATE PROCEDURE [dbo].[sp_Problem_Search_By_Page]
@Filter varchar(5000),
@ReqStatusID int,
@SortBy int,
@SortOrder int,
@CurrentPage int,
@PageSize int,
@DateMode int,
@StartDate varchar(22),
@EndDate varchar(22),
@TotalRecords int output
AS

/*

	@ReqStatusID = 1	New
	@ReqStatusID = 2	Open
	@ReqStatusID = 3	Closed
	@ReqStatusID = 4	Pending
	@ReqStatusID = 5	Stalled
	@ReqStatusID = 6	Dead
	@ReqStatusID = 7	Re-Opened
	
	@ReqStatusID = 100	Current (New, Open, Pending, Re-Opened)
	@ReqStatusID = 101	Doesn't Matter (New, Open, Closed, Pending, Stalled, Dead, Re-Opened)

*/

-- Create A Temporary Table To Hold The Current Page Of Data --

DECLARE @str1 as nvarchar(max)
DECLARE @SortIndex As nvarchar(255)

SET @str1 = 'SELECT DISTINCT TOP 100 PERCENT (vew_ProblemAndAuditDetails.ProblemID), 
	vew_ProblemAndAuditDetails.DateEntered, 
	vew_ProblemAndAuditDetails.ProblemStatusID,
	vew_ProblemAndAuditDetails.HDUserID,
	vew_ProblemAndAuditDetails.FirstName As CFN, 
	vew_ProblemAndAuditDetails.LastName As CLN, 
	vew_ProblemAndAuditDetails.ReqFirstName As RFN, 
	vew_ProblemAndAuditDetails.ReqLastName As RLN, 	
	vew_ProblemAndAuditDetails.Subject,
	vew_ProblemAndAuditDetails.GroupID, 
	vew_ProblemAndAuditDetails.UserID, 
	vew_ProblemAndAuditDetails.PriorityID,
	tbl_QueueDueDates.DisplayLabel AS PriorityLabel,
	vew_ProblemAndAuditDetails.DueDate, 
	vew_ProblemAndAuditDetails.EstSolDate,
	vew_ProblemAndAuditDetails.ProblemLocked,
	tbl_ProblemStatus.ProblemStatusTitle, 
	tbl_Users.FirstName As LFN, tbl_Users.LastName As LLN, 
	tbl_Groups.GroupName,
	DUMYTABLE.FirstName AS OFN, DUMYTABLE.LastName AS OLN, 
	DUMYTABLE2.FirstName AS LOCKFN, DUMYTABLE2.LastName AS LOCKLN,
	(select count(ProblemID) from tbl_ProblemAuditAttach Where ProblemID= vew_ProblemAndAuditDetails.ProblemID) As NumAtt
	FROM vew_ProblemAndAuditDetails
	LEFT OUTER JOIN tbl_QueueDueDates WITH (NOLOCK) ON vew_ProblemAndAuditDetails.PriorityID = tbl_QueueDueDates.PriorityID AND vew_ProblemAndAuditDetails.QueueID = tbl_QueueDueDates.QueueID
	LEFT OUTER JOIN tbl_Users DUMYTABLE WITH (NOLOCK) ON vew_ProblemAndAuditDetails.UserID = DUMYTABLE.UserID 
	LEFT OUTER JOIN tbl_Users DUMYTABLE2 WITH (NOLOCK) ON vew_ProblemAndAuditDetails.ProblemLocked = DUMYTABLE2.UserID 
	Left Outer Join tbl_ProblemStatus WITH (NOLOCK) On vew_ProblemAndAuditDetails.ProblemStatusID = tbl_ProblemStatus.ProblemStatusID 
	Left Outer Join tbl_Users WITH (NOLOCK) On vew_ProblemAndAuditDetails.HDUserID = tbl_Users.UserID
	Left Outer Join tbl_Groups WITH (NOLOCK) On vew_ProblemAndAuditDetails.GroupID = tbl_Groups.GroupID 
	WHERE (' + @Filter + ')'


	IF @ReqStatusID < 100
	BEGIN
		SET @str1 = @str1 + ' And vew_ProblemAndAuditDetails.ProblemStatusID = ' + CAST(@ReqStatusID AS varchar)
	END

	IF @ReqStatusID = 100
	BEGIN
		SET @str1 = @str1 + ' And (vew_ProblemAndAuditDetails.ProblemStatusID IN (1, 2, 7, 4))'
	END

	IF @ReqStatusID = 101
	BEGIN
		SET @str1 = @str1 + ' And (vew_ProblemAndAuditDetails.ProblemStatusID IN (1, 2, 3, 4, 5, 6, 7, 8))'
	END


	IF @DateMode = 1
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ProblemAndAuditDetails.DateEntered BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 2
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ProblemAndAuditDetails.DueDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 3
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ProblemAndAuditDetails.EstSolDate BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	IF @DateMode = 4
	BEGIN
		SET @str1 = @str1 + ' AND (vew_ProblemAndAuditDetails.Closed BETWEEN ' + char(39) + @StartDate + ' 0:00:00' +  char(39) + ' AND ' +  char(39) + @EndDate + ' 23:59:59' +  char(39) + ')' 
	END

	SET @str1 = @str1 + ' ORDER BY '
	SET @SortIndex = 'RecordID'

	IF @SortBy = 0
	BEGIN
		SET @str1 = @str1 + 'ProblemID'
	END
	IF @SortBy = 1
	BEGIN
		SET @str1 = @str1 + 'ProblemID'
	END
	IF @SortBy = 2
	BEGIN
		SET @str1 = @str1 + 'tbl_ProblemStatus.ProblemStatusTitle'
		SET @SortIndex = 'RecordStatusTitle'
	END
	IF @SortBy = 3
	BEGIN
		SET @str1 = @str1 + 'vew_ProblemAndAuditDetails.PriorityID'
		SET @SortIndex = 'PriorityID'
	END
	IF @SortBy = 4
	BEGIN
		SET @str1 = @str1 + 'vew_ProblemAndAuditDetails.DueDate'
		SET @SortIndex = 'DueDate'
	END
	IF @SortBy = 5
	BEGIN
		SET @str1 = @str1 + 'vew_ProblemAndAuditDetails.FirstName'
		SET @SortIndex = 'CFN, CLN'
	END
	IF @SortBy = 6
	BEGIN
		SET @str1 = @str1 + 'vew_ProblemAndAuditDetails.Subject'
		SET @SortIndex = 'Subject'
	END
	IF @SortBy = 7
	BEGIN
		SET @str1 = @str1 + 'OFN'
		SET @SortIndex = 'OFN, OLN'
	END
	IF @SortBy = 8
	BEGIN
		SET @str1 = @str1 + 'tbl_Groups.GroupName'
		SET @SortIndex = 'GroupName'
	END
	IF @SortBy = 9
	BEGIN
		SET @str1 = @str1 + 'LFN'
		SET @SortIndex = 'LFN, LLN'
	END
	IF @SortBy = 10
	BEGIN
		SET @str1 = @str1 + 'vew_ProblemAndAuditDetails.DateEntered'
		SET @SortIndex = 'DateEntered'
	END
	IF @SortOrder = 0
	BEGIN
		SET @str1 = @str1 + ' DESC'
	END
	IF @SortOrder = 1
	BEGIN
		SET @str1 = @str1 + ' ASC'
	END


CREATE TABLE #TempTable
(
	ID int IDENTITY,
	[Timestamp] timestamp, 
	RecordID int,
	DateEntered datetime,
	RecordStatusID int,
	HDUserID int,
	CFN nvarchar(100),
	CLN nvarchar(100),
	RFN nvarchar(100),
	RLN nvarchar(100),
	Subject nvarchar(500),
	GroupID int,
	UserID int,
	PriorityID int,
	PriorityLabel nvarchar(255),
	DueDate datetime,
	EstSolDate datetime,
	RecordLocked int,
	RecordStatusTitle nvarchar(50),
	LFN nvarchar(30),
	LLN nvarchar(30),
	GroupName nvarchar(50),
	OFN nvarchar(30),
	OLN nvarchar(30),
	LOCKFN nvarchar(30),
	LOCKLN nvarchar(30),
	NumAtt int
)

-- Create Index for TempTable with Unique Index Name
DECLARE @strIndexQuery nvarchar(1000)
SET @strIndexQuery = 'CREATE INDEX IX_TempTable_' + REPLACE(CAST(NEWID() As varchar(50)), '-', '_') + ' ON tempdb..#TempTable (' + @SortIndex + ')'
EXEC(@strIndexQuery)

-- Fill The Temporary Table With Appropriate Problem Data --
INSERT INTO #TempTable
(
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt
)


EXEC(@str1)


-- Create A Variable To Identify The First And Last Record That Should Be Selected --

DECLARE @FirstRec int, @LastRec int
SELECT @FirstRec = (@CurrentPage - 1) * @PageSize
SELECT @LastRec = (@CurrentPage * @PageSize + 1)

-- Select One Page Of Data Based On The Record Numbers Above --

SELECT
	RecordID,
	DateEntered,
	RecordStatusID,
	HDUserID,
	CFN,
	CLN,
	RFN,
	RLN,
	Subject,
	GroupID,
	UserID,
	PriorityID,
	PriorityLabel,
	DueDate,
	EstSolDate,
	RecordLocked,
	RecordStatusTitle,
	LFN,
	LLN,
	GroupName,
	OFN,
	OLN,
	LOCKFN,
	LOCKLN,
	NumAtt	
	FROM #TempTable
WHERE
	ID > @FirstRec
AND
	ID < @LastRec 
ORDER BY ID ASC

-- Return The Total Number Of Records Available As An Output Parameter --

SELECT @TotalRecords = COUNT(*) FROM #TempTable
GO

IF @@ERROR<>0 OR @@TRANCOUNT=0 BEGIN IF @@TRANCOUNT>0 ROLLBACK SET NOEXEC ON END
GO
-- COMMITTING TRANSACTION 
PRINT 'Committing transaction '
IF @@TRANCOUNT>0
	COMMIT TRAN
GO

SET NOEXEC OFF
GO
